#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data1 = {
    "Jewish American non-fiction writers": "كتاب غير روائيين أمريكيون يهود",
    "Non-fiction books about the United States Army": "كتب غير خيالية عن القوات المسلحة الأمريكية",
    "non-fiction writers from northern ireland": "كتاب غير روائيين من أيرلندا الشمالية",
    "non-fiction writers from russian empire": "كتاب غير روائيين من الإمبراطورية الروسية",
    "1550 non-fiction books": "كتب غير خيالية 1550",
    "1550s non-fiction books": "كتب غير خيالية عقد 1550",
    "20th-century american non-fiction writers": "كتاب غير روائيين أمريكيون في القرن 20",
    "20th-century australian non-fiction writers": "كتاب غير روائيين أستراليون في القرن 20",
    "20th-century austrian non-fiction writers": "كتاب غير روائيين نمساويون في القرن 20",
    "20th-century bangladeshi non-fiction writers": "كتاب غير روائيين بنغلاديشيون في القرن 20",
    "20th-century belgian non-fiction writers": "كتاب غير روائيين بلجيكيون في القرن 20",
    "20th-century brazilian non-fiction writers": "كتاب غير روائيين برازيليون في القرن 20",
    "20th-century british non-fiction writers": "كتاب غير روائيين بريطانيون في القرن 20",
    "20th-century canadian non-fiction writers": "كتاب غير روائيين كنديون في القرن 20",
    "20th-century chilean non-fiction writers": "كتاب غير روائيين تشيليون في القرن 20",
    "20th-century chinese non-fiction writers": "كتاب غير روائيين صينيون في القرن 20",
    "20th-century croatian non-fiction writers": "كتاب غير روائيين كروات في القرن 20",
    "20th-century czech non-fiction writers": "كتاب غير روائيين تشيكيون في القرن 20",
    "20th-century danish non-fiction writers": "كتاب غير روائيين دنماركيون في القرن 20",
    "20th-century dutch non-fiction writers": "كتاب غير روائيين هولنديون في القرن 20",
    "20th-century egyptian non-fiction writers": "كتاب غير روائيين مصريون في القرن 20",
    "20th-century english non-fiction writers": "كتاب غير روائيين إنجليز في القرن 20",
    "20th-century finnish non-fiction writers": "كتاب غير روائيين فنلنديون في القرن 20",
    "20th-century french non-fiction writers": "كتاب غير روائيين فرنسيون في القرن 20",
    "20th-century german non-fiction writers": "كتاب غير روائيين ألمان في القرن 20",
    "20th-century greek non-fiction writers": "كتاب غير روائيين يونانيون في القرن 20",
    "20th-century indian non-fiction writers": "كتاب غير روائيين هنود في القرن 20",
    "20th-century irish non-fiction writers": "كتاب غير روائيين أيرلنديون في القرن 20",
    "20th-century israeli non-fiction writers": "كتاب غير روائيين إسرائيليون في القرن 20",
    "20th-century italian non-fiction writers": "كتاب غير روائيين إيطاليون في القرن 20",
    "20th-century japanese non-fiction writers": "كتاب غير روائيين يابانيون في القرن 20",
    "20th-century lithuanian non-fiction writers": "كتاب غير روائيين ليتوانيون في القرن 20",
    "20th-century mexican non-fiction writers": "كتاب غير روائيين مكسيكيون في القرن 20",
    "20th-century non-fiction books": "كتب غير خيالية القرن 20",
    "20th-century non-fiction writers by nationality": "كتاب غير روائيين في القرن 20 حسب الجنسية",
    "20th-century non-fiction writers from northern ireland": "كتاب غير روائيين من أيرلندا الشمالية في القرن 20",
    "20th-century non-fiction writers from russian empire": "كتاب غير روائيين من الإمبراطورية الروسية في القرن 20",
    "20th-century non-fiction writers": "كتاب غير روائيين في القرن 20",
    "20th-century norwegian non-fiction writers": "كتاب غير روائيين نرويجيون في القرن 20",
    "20th-century polish non-fiction writers": "كتاب غير روائيين بولنديون في القرن 20",
    "20th-century portuguese non-fiction writers": "كتاب غير روائيين برتغاليون في القرن 20",
    "20th-century puerto rican non-fiction writers": "كتاب غير روائيين بورتوريكيون في القرن 20",
    "20th-century russian non-fiction writers": "كتاب غير روائيين روس في القرن 20",
    "20th-century scottish non-fiction writers": "كتاب غير روائيين إسكتلنديون في القرن 20",
    "20th-century south korean non-fiction writers": "كتاب غير روائيين كوريون جنوبيون في القرن 20",
    "20th-century spanish non-fiction writers": "كتاب غير روائيين إسبان في القرن 20",
    "20th-century swedish non-fiction writers": "كتاب غير روائيين سويديون في القرن 20",
    "20th-century swiss non-fiction writers": "كتاب غير روائيين سويسريون في القرن 20",
    "20th-century turkish non-fiction writers": "كتاب غير روائيين أتراك في القرن 20",
    "20th-century welsh non-fiction writers": "كتاب غير روائيين ويلزيون في القرن 20",
    "2nd-century non-fiction writers": "كتاب غير روائيين في القرن 2",
    "3rd-century non-fiction writers": "كتاب غير روائيين في القرن 3",
    "4th-century non-fiction writers": "كتاب غير روائيين في القرن 4",
    "5th-century non-fiction writers": "كتاب غير روائيين في القرن 5",
    "6th-century non-fiction writers": "كتاب غير روائيين في القرن 6",
    "7th-century indian non-fiction writers": "كتاب غير روائيين هنود في القرن 7",
    "7th-century non-fiction writers": "كتاب غير روائيين في القرن 7",
    "8th-century indian non-fiction writers": "كتاب غير روائيين هنود في القرن 8",
    "8th-century non-fiction writers": "كتاب غير روائيين في القرن 8",
    "9th-century indian non-fiction writers": "كتاب غير روائيين هنود في القرن 9",
    "9th-century non-fiction writers": "كتاب غير روائيين في القرن 9",
    "academic journals published by non-profit organisations of united kingdom": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في المملكة المتحدة",
    "academic journals published by non-profit organizations of brazil": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في البرازيل",
    "academic journals published by non-profit organizations of canada": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في كندا",
    "academic journals published by non-profit organizations of chile": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في تشيلي",
    "academic journals published by non-profit organizations of colombia": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في كولومبيا",
    "academic journals published by non-profit organizations of costa rica": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في كوستاريكا",
    "academic journals published by non-profit organizations of united states": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية في الولايات المتحدة",
    "academic journals published by non-profit organizations": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية",
    "academic journals published by non-profit publishers": "نشرات دورية أكاديمية نشرتها ناشرون غير ربحيون",
    "african-american non-fiction writers": "كتاب غير روائيين أمريكيون أفارقة",
    "albanian male non-fiction writers": "كتاب غير روائيين ذكور ألبان",
    "albanian non-fiction writers": "كتاب غير روائيين ألبان",
    "algerian non-fiction writers": "كتاب غير روائيين جزائريون",
    "american male non-fiction writers": "كتاب غير روائيين ذكور أمريكيون",
    "american non-fiction books by writer": "كتب أمريكية غير خيالية حسب الكاتب",
    "american non-fiction books": "كتب أمريكية غير خيالية",
    "american non-fiction crime writers": "كتاب جريمة غير روائيين أمريكيون",
    "american non-fiction environmental writers": "كتاب بيئة غير روائيين أمريكيون",
    "american non-fiction writers by century": "كتاب غير روائيين أمريكيون حسب القرن",
    "american non-fiction writers": "كتاب غير روائيين أمريكيون",
    "american women non-fiction writers": "كاتبات غير روائيات أمريكيات",
    "angolan non-fiction writers": "كتاب غير روائيين أنغوليون",
    "arab non-fiction writers": "كتاب غير روائيين عرب",
    "argentine male non-fiction writers": "كتاب غير روائيين ذكور أرجنتينيون",
    "argentine non-fiction books": "كتب أرجنتينية غير خيالية",
    "argentine non-fiction writers": "كتاب غير روائيين أرجنتينيون",
    "argentine women non-fiction writers": "كاتبات غير روائيات أرجنتينيات",
    "armenian non-fiction writers": "كتاب غير روائيين أرمن",
    "australian male non-fiction writers": "كتاب غير روائيين ذكور أستراليون",
    "australian non-fiction books": "كتب أسترالية غير خيالية",
    "australian non-fiction crime writers": "كتاب جريمة غير روائيين أستراليون",
    "australian non-fiction writers by century": "كتاب غير روائيين أستراليون حسب القرن",
    "australian non-fiction writers": "كتاب غير روائيين أستراليون",
    "australian women non-fiction writers": "كاتبات غير روائيات أستراليات",
    "austrian male non-fiction writers": "كتاب غير روائيين ذكور نمساويون",
    "austrian non-fiction books": "كتب نمساوية غير خيالية",
    "austrian non-fiction writers": "كتاب غير روائيين نمساويون",
    "austrian women non-fiction writers": "كاتبات غير روائيات نمساويات",
    "azerbaijani non-fiction books": "كتب أذربيجانية غير خيالية",
    "azerbaijani non-fiction writers": "كتاب غير روائيين أذربيجانيون",
    "bahraini non-fiction writers": "كتاب غير روائيين بحرينيون",
    "bangladeshi non-fiction books": "كتب بنغلاديشية غير خيالية",
    "bangladeshi non-fiction writers": "كتاب غير روائيين بنغلاديشيون",
    "belarusian male non-fiction writers": "كتاب غير روائيين ذكور بيلاروسيون",
    "belarusian non-fiction writers": "كتاب غير روائيين بيلاروسيون",
    "belgian male non-fiction writers": "كتاب غير روائيين ذكور بلجيكيون",
    "belgian non-fiction writers by century": "كتاب غير روائيين بلجيكيون حسب القرن",
    "belgian non-fiction writers": "كتاب غير روائيين بلجيكيون",
    "beninese non-fiction writers": "كتاب غير روائيين بنينيون",
    "bermudian non-fiction writers": "كتاب غير روائيين برموديون",
    "bolivian male non-fiction writers": "كتاب غير روائيين ذكور بوليفيون",
    "bolivian non-fiction writers": "كتاب غير روائيين بوليفيون",
    "bosnia and herzegovina non-fiction writers": "كتاب غير روائيين بوسنيون",
    "botswana non-fiction writers": "كتاب غير روائيين بوتسوانيون",
    "brazilian male non-fiction writers": "كتاب غير روائيين ذكور برازيليون",
    "brazilian non-fiction books": "كتب برازيلية غير خيالية",
    "brazilian non-fiction writers by century": "كتاب غير روائيين برازيليون حسب القرن",
    "brazilian non-fiction writers": "كتاب غير روائيين برازيليون",
    "brazilian women non-fiction writers": "كاتبات غير روائيات برازيليات",
    "british male non-fiction writers": "كتاب غير روائيين ذكور بريطانيون",
    "british non-fiction books": "كتب بريطانية غير خيالية",
    "british non-fiction crime writers": "كتاب جريمة غير روائيين بريطانيون",
    "british non-fiction environmental writers": "كتاب بيئة غير روائيين بريطانيون",
    "british non-fiction writers by century": "كتاب غير روائيين بريطانيون حسب القرن",
    "british non-fiction writers": "كتاب غير روائيين بريطانيون",
    "british women non-fiction writers": "كاتبات غير روائيات بريطانيات",
    "bulgarian non-fiction writers": "كتاب غير روائيين بلغاريون",
    "burkinabe non-fiction writers": "كتاب غير روائيين بوركينابيون",
    "burmese non-fiction writers": "كتاب غير روائيين بورميون",
    "burundian non-fiction writers": "كتاب غير روائيين بورونديون",
    "cameroonian non-fiction writers": "كتاب غير روائيين كاميرونيون",
    "canadian male non-fiction writers": "كتاب غير روائيين ذكور كنديون",
    "canadian non-fiction books": "كتب كندية غير خيالية",
    "canadian non-fiction writers by century": "كتاب غير روائيين كنديون حسب القرن",
    "canadian non-fiction writers": "كتاب غير روائيين كنديون",
    "canadian women non-fiction writers": "كاتبات غير روائيات كنديات",
    "cape verdean non-fiction writers": "كتاب غير روائيين أخضريون",
    "central african republic non-fiction writers": "كتاب غير روائيين أفارقة أوسطيون",
    "chadian non-fiction writers": "كتاب غير روائيين تشاديون",
    "chilean male non-fiction writers": "كتاب غير روائيين ذكور تشيليون",
    "chilean non-fiction writers": "كتاب غير روائيين تشيليون",
    "chinese male non-fiction writers": "كتاب غير روائيين ذكور صينيون",
    "chinese non-fiction books": "كتب صينية غير خيالية",
    "chinese non-fiction writers": "كتاب غير روائيين صينيون",
    "chinese women non-fiction writers": "كاتبات غير روائيات صينيات",
    "colombian male non-fiction writers": "كتاب غير روائيين ذكور كولومبيون",
    "colombian non-fiction books": "كتب كولومبية غير خيالية",
    "colombian non-fiction writers": "كتاب غير روائيين كولومبيون",
    "comorian non-fiction writers": "كتاب غير روائيين قمريون",
    "croatian non-fiction writers by century": "كتاب غير روائيين كروات حسب القرن",
    "croatian non-fiction writers": "كتاب غير روائيين كروات",
    "cuban male non-fiction writers": "كتاب غير روائيين ذكور كوبيون",
    "cuban non-fiction writers": "كتاب غير روائيين كوبيون",
    "cypriot non-fiction writers": "كتاب غير روائيين قبرصيون",
    "czech male non-fiction writers": "كتاب غير روائيين ذكور تشيكيون",
    "czech non-fiction writers by century": "كتاب غير روائيين تشيكيون حسب القرن",
    "czech non-fiction writers": "كتاب غير روائيين تشيكيون",
    "czech women non-fiction writers": "كاتبات غير روائيات تشيكيات",
    "danish male non-fiction writers": "كتاب غير روائيين ذكور دنماركيون",
    "danish non-fiction books": "كتب دنماركية غير خيالية",
    "danish non-fiction writers by century": "كتاب غير روائيين دنماركيون حسب القرن",
    "danish non-fiction writers": "كتاب غير روائيين دنماركيون",
    "danish women non-fiction writers": "كاتبات غير روائيات دنماركيات",
    "defunct non-profit organizations based in united states": "منظمات غير ربحية سابقة مقرها في الولايات المتحدة",
    "democratic republic of congo non-fiction writers": "كتاب غير روائيين كونغويون ديمقراطيون",
    "dutch male non-fiction writers": "كتاب غير روائيين ذكور هولنديون",
    "dutch non-fiction books": "كتب هولندية غير خيالية",
    "dutch non-fiction writers by century": "كتاب غير روائيين هولنديون حسب القرن",
    "dutch non-fiction writers": "كتاب غير روائيين هولنديون",
    "dutch women non-fiction writers": "كاتبات غير روائيات هولنديات",
    "economy of lebanon-related lists": "اقتصاد قوائم متعلقة بلبنان",
    "egyptian male non-fiction writers": "كتاب غير روائيين ذكور مصريون",
    "egyptian non-fiction books": "كتب مصرية غير خيالية",
    "egyptian non-fiction writers": "كتاب غير روائيين مصريون",
    "egyptian women non-fiction writers": "كاتبات غير روائيات مصريات",
    "emirati non-fiction books": "كتب إماراتية غير خيالية",
    "emirati non-fiction writers": "كتاب غير روائيين إماراتيون",
    "english male non-fiction writers": "كتاب غير روائيين ذكور إنجليز",
    "english non-fiction books": "كتب إنجليزية غير خيالية",
    "english non-fiction crime writers": "كتاب جريمة غير روائيين إنجليز",
    "english non-fiction writers by century": "كتاب غير روائيين إنجليز حسب القرن",
    "english non-fiction writers": "كتاب غير روائيين إنجليز",
    "english women non-fiction writers": "كاتبات غير روائيات إنجليزيات",
    "eritrean non-fiction writers": "كتاب غير روائيين إريتريون",
    "estonian male non-fiction writers": "كتاب غير روائيين ذكور إستونيون",
    "estonian non-fiction books": "كتب إستونية غير خيالية",
    "estonian non-fiction writers": "كتاب غير روائيين إستونيون",
    "estonian women non-fiction writers": "كاتبات غير روائيات إستونيات",
    "ethiopian non-fiction writers": "كتاب غير روائيين إثيوبيون",
    "filipino non-fiction writers": "كتاب غير روائيين فلبينيون",
    "films based on non-fiction books about organized crime": "أفلام مبنية على كتب غير خيالية عن جريمة منظمة",
    "films based on non-fiction books": "أفلام مبنية على كتب غير خيالية",
    "finnish male non-fiction writers": "كتاب غير روائيين ذكور فنلنديون",
    "finnish non-fiction books": "كتب فنلندية غير خيالية",
    "finnish non-fiction writers by century": "كتاب غير روائيين فنلنديون حسب القرن",
    "finnish non-fiction writers": "كتاب غير روائيين فنلنديون",
    "finnish women non-fiction writers": "كاتبات غير روائيات فنلنديات",
    "french male non-fiction writers": "كتاب غير روائيين ذكور فرنسيون",
    "french non-fiction books": "كتب فرنسية غير خيالية",
    "french non-fiction writers by century": "كتاب غير روائيين فرنسيون حسب القرن",
    "french non-fiction writers": "كتاب غير روائيين فرنسيون",
    "french women non-fiction writers": "كاتبات غير روائيات فرنسيات",
    "gabonese non-fiction writers": "كتاب غير روائيين غابونيون",
    "gambian non-fiction writers": "كتاب غير روائيين غامبيون",
    "german male non-fiction writers": "كتاب غير روائيين ذكور ألمان",
    "german non-fiction books": "كتب ألمانية غير خيالية",
    "german non-fiction writers by century": "كتاب غير روائيين ألمان حسب القرن",
    "german non-fiction writers": "كتاب غير روائيين ألمان",
    "german women non-fiction writers": "كاتبات غير روائيات ألمانيات",
    "ghanaian non-fiction writers": "كتاب غير روائيين غانيون",
    "gibraltarian non-fiction writers": "كتاب غير روائيين جبل طارقيون",
    "greek male non-fiction writers": "كتاب غير روائيين ذكور يونانيون",
    "greek non-fiction writers by century": "كتاب غير روائيين يونانيون حسب القرن",
    "greek non-fiction writers": "كتاب غير روائيين يونانيون",
    "greek women non-fiction writers": "كاتبات غير روائيات يونانيات",
    "greenlandic non-fiction writers": "كتاب غير روائيين جرينلانديون",
    "guadeloupean non-fiction writers": "كتاب غير روائيين غواديلوبيون",
    "guyanese non-fiction writers": "كتاب غير روائيين غيانيون",
    "haitian male non-fiction writers": "كتاب غير روائيين ذكور هايتيون",
    "haitian non-fiction writers": "كتاب غير روائيين هايتيون",
    "hong kong non-fiction books": "كتب هونغ كونغية غير خيالية",
    "hungarian male non-fiction writers": "كتاب غير روائيين ذكور مجريون",
    "hungarian non-fiction writers": "كتاب غير روائيين مجريون",
    "hungarian women non-fiction writers": "كاتبات غير روائيات مجريات",
    "icelandic non-fiction writers": "كتاب غير روائيين آيسلنديون",
    "indian male non-fiction writers": "كتاب غير روائيين ذكور هنود",
    "indian non-fiction books": "كتب هندية غير خيالية",
    "indian non-fiction environmental writers": "كتاب بيئة غير روائيين هنود",
    "indian non-fiction writers by century": "كتاب غير روائيين هنود حسب القرن",
    "indian non-fiction writers": "كتاب غير روائيين هنود",
    "indian women non-fiction writers": "كاتبات غير روائيات هنديات",
    "indonesian non-fiction books": "كتب إندونيسية غير خيالية",
    "indonesian non-fiction writers": "كتاب غير روائيين إندونيسيون",
    "international non-profit organizations": "منظمات غير ربحية دولية",
    "iranian non-fiction writers": "كتاب غير روائيين إيرانيون",
    "iraqi non-fiction books": "كتب عراقية غير خيالية",
    "iraqi non-fiction writers": "كتاب غير روائيين عراقيون",
    "irish male non-fiction writers": "كتاب غير روائيين ذكور أيرلنديون",
    "irish non-fiction books": "كتب أيرلندية غير خيالية",
    "irish non-fiction writers by century": "كتاب غير روائيين أيرلنديون حسب القرن",
    "irish non-fiction writers": "كتاب غير روائيين أيرلنديون",
    "irish women non-fiction writers": "كاتبات غير روائيات أيرلنديات",
    "israeli male non-fiction writers": "كتاب غير روائيين ذكور إسرائيليون",
    "israeli non-fiction books": "كتب إسرائيلية غير خيالية",
    "israeli non-fiction writers by century": "كتاب غير روائيين إسرائيليون حسب القرن",
    "israeli non-fiction writers": "كتاب غير روائيين إسرائيليون",
    "israeli women non-fiction writers": "كاتبات غير روائيات إسرائيليات",
    "italian male non-fiction writers": "كتاب غير روائيين ذكور إيطاليون",
    "italian non-fiction books": "كتب إيطالية غير خيالية",
    "italian non-fiction writers by century": "كتاب غير روائيين إيطاليون حسب القرن",
    "italian non-fiction writers": "كتاب غير روائيين إيطاليون",
    "italian women non-fiction writers": "كاتبات غير روائيات إيطاليات",
    "ivorian non-fiction writers": "كتاب غير روائيين إيفواريون",
    "jamaican male non-fiction writers": "كتاب غير روائيين ذكور جامايكيون",
    "jamaican non-fiction writers": "كتاب غير روائيين جامايكيون",
    "japanese male non-fiction writers": "كتاب غير روائيين ذكور يابانيون",
    "japanese non-fiction books": "كتب يابانية غير خيالية",
    "japanese non-fiction writers by century": "كتاب غير روائيين يابانيون حسب القرن",
    "japanese non-fiction writers": "كتاب غير روائيين يابانيون",
    "japanese women non-fiction writers": "كاتبات غير روائيات يابانيات",
    "jewish non-fiction writers by nationality": "كتاب غير روائيين يهود حسب الجنسية",
    "jewish non-fiction writers": "كتاب غير روائيين يهود",
    "jewish women non-fiction writers": "كاتبات غير روائيات يهوديات",
    "jordanian non-fiction writers": "كتاب غير روائيين أردنيون",
    "kenyan non-fiction writers": "كتاب غير روائيين كينيون",
    "korean non-fiction books": "كتب كورية غير خيالية",
    "korean non-fiction writers": "كتاب غير روائيين كوريون",
    "kosovan non-fiction writers": "كتاب غير روائيين كوسوفيون",
    "kuwaiti non-fiction writers": "كتاب غير روائيين كويتيون",
    "latvian male non-fiction writers": "كتاب غير روائيين ذكور لاتفيون",
    "latvian non-fiction writers": "كتاب غير روائيين لاتفيون",
    "latvian women non-fiction writers": "كاتبات غير روائيات لاتفيات",
    "lebanese non-fiction writers": "كتاب غير روائيين لبنانيون",
    "lebanon-related lists": "قوائم متعلقة بلبنان",
    "lesotho non-fiction writers": "كتاب غير روائيين ليسوتيون",
    "liberian non-fiction books": "كتب ليبيرية غير خيالية",
    "liberian non-fiction writers": "كتاب غير روائيين ليبيريون",
    "libyan non-fiction writers": "كتاب غير روائيين ليبيون",
    "lists of non-fiction books": "قوائم كتب غير خيالية",
    "lithuanian male non-fiction writers": "كتاب غير روائيين ذكور ليتوانيون",
    "lithuanian non-fiction writers": "كتاب غير روائيين ليتوانيون",
    "lithuanian women non-fiction writers": "كاتبات غير روائيات ليتوانيات",
    "luxembourgian male non-fiction writers": "كتاب غير روائيين ذكور لوكسمبورغيون",
    "luxembourgian non-fiction writers": "كتاب غير روائيين لوكسمبورغيون",
    "macedonian non-fiction writers": "كتاب غير روائيين مقدونيون",
    "malawian non-fiction writers": "كتاب غير روائيين ملاويون",
    "malaysian non-fiction books": "كتب ماليزية غير خيالية",
    "malaysian non-fiction writers": "كتاب غير روائيين ماليزيون",
    "maldivian non-fiction writers": "كتاب غير روائيين مالديفيون",
    "male non-fiction writers by nationality": "كتاب غير روائيين ذكور حسب الجنسية",
    "male non-fiction writers from northern ireland": "كتاب غير روائيين ذكور من أيرلندا الشمالية",
    "male non-fiction writers": "كتاب غير روائيين ذكور",
    "malian non-fiction writers": "كتاب غير روائيين ماليون",
    "maltese non-fiction writers": "كتاب غير روائيين مالطيون",
    "mauritanian non-fiction writers": "كتاب غير روائيين موريتانيون",
    "mauritian non-fiction writers": "كتاب غير روائيين موريشيوسيون",
    "mexican male non-fiction writers": "كتاب غير روائيين ذكور مكسيكيون",
    "mexican non-fiction books": "كتب مكسيكية غير خيالية",
    "mexican non-fiction writers by century": "كتاب غير روائيين مكسيكيون حسب القرن",
    "mexican non-fiction writers": "كتاب غير روائيين مكسيكيون",
    "mexican women non-fiction writers": "كاتبات غير روائيات مكسيكيات",
    "moldovan male non-fiction writers": "كتاب غير روائيين ذكور مولدوفيون",
    "moldovan non-fiction writers": "كتاب غير روائيين مولدوفيون",
    "moroccan non-fiction writers": "كتاب غير روائيين مغاربة",
    "mozambican non-fiction writers": "كتاب غير روائيين موزمبيقيون",
    "namibian non-fiction writers": "كتاب غير روائيين ناميبيون",
    "nepalese non-fiction books": "كتب نيبالية غير خيالية",
    "nepalese non-fiction writers": "كتاب غير روائيين نيباليون",
    "nicaraguan non-fiction writers": "كتاب غير روائيين نيكاراغويون",
    "nigerian non-fiction books": "كتب نيجيرية غير خيالية",
    "nigerian non-fiction writers": "كتاب غير روائيين نيجيريون",
    "nigerien non-fiction writers": "كتاب غير روائيين نيجريون",
    "non-combat military accidents of united states": "حوادث عسكرية غير قتالية في الولايات المتحدة",
    "non-combat military accidents": "حوادث عسكرية غير قتالية",
    "non-combat military operations by country": "عمليات عسكرية غير قتالية حسب البلد",
    "non-combat military operations involving argentina": "عمليات عسكرية غير قتالية تشمل الأرجنتين",
    "non-combat military operations involving australia": "عمليات عسكرية غير قتالية تشمل أستراليا",
    "non-combat military operations involving canada": "عمليات عسكرية غير قتالية تشمل كندا",
    "non-combat military operations involving france": "عمليات عسكرية غير قتالية تشمل فرنسا",
    "non-combat military operations involving germany": "عمليات عسكرية غير قتالية تشمل ألمانيا",
    "non-combat military operations involving india": "عمليات عسكرية غير قتالية تشمل الهند",
    "non-combat military operations involving israel": "عمليات عسكرية غير قتالية تشمل إسرائيل",
    "non-combat military operations involving nepal": "عمليات عسكرية غير قتالية تشمل نيبال",
    "non-combat military operations involving new zealand": "عمليات عسكرية غير قتالية تشمل نيوزيلندا",
    "non-combat military operations involving pakistan": "عمليات عسكرية غير قتالية تشمل باكستان",
    "non-combat military operations involving south korea": "عمليات عسكرية غير قتالية تشمل كوريا الجنوبية",
    "non-combat military operations involving soviet union": "عمليات عسكرية غير قتالية تشمل الاتحاد السوفيتي",
    "non-combat military operations involving thailand": "عمليات عسكرية غير قتالية تشمل تايلاند",
    "non-combat military operations involving united kingdom": "عمليات عسكرية غير قتالية تشمل المملكة المتحدة",
    "non-combat military operations involving united states": "عمليات عسكرية غير قتالية تشمل الولايات المتحدة",
    "non-combat military operations": "عمليات عسكرية غير قتالية",
    "non-equilibrium thermodynamics": "ترموديناميك اللاتوازن",
    "non-fiction books about acting": "كتب غير خيالية عن التمثيل",
    "non-fiction books about advertising": "كتب غير خيالية عن الدعاية والإعلان",
    "non-fiction books about animals": "كتب غير خيالية عن حيوانات",
    "non-fiction books about assassination of john f. kennedy": "كتب غير خيالية عن اغتيال جون كينيدي",
    "non-fiction books about assassination of": "كتب غير خيالية عن اغتيال",
    "non-fiction books about ballet": "كتب غير خيالية عن باليه",
    "non-fiction books about bears": "كتب غير خيالية عن دبيات",
    "non-fiction books about birds": "كتب غير خيالية عن طيور",
    "non-fiction books about bosnian war": "كتب غير خيالية عن الحرب البوسنية",
    "non-fiction books about cancer": "كتب غير خيالية عن السرطان",
    "non-fiction books about cannabis": "كتب غير خيالية عن القنب",
    "non-fiction books about cats": "كتب غير خيالية عن القطط",
    "non-fiction books about civil rights movement": "كتب غير خيالية عن حركة الحقوق المدنية",
    "non-fiction books about crime in canada": "كتب غير خيالية عن جريمة في كندا",
    "non-fiction books about crime in united states": "كتب غير خيالية عن جريمة في الولايات المتحدة",
    "non-fiction books about crime": "كتب غير خيالية عن جريمة",
    "non-fiction books about criminals": "كتب غير خيالية عن مجرمون",
    "non-fiction books about dinosaurs": "كتب غير خيالية عن ديناصورات",
    "non-fiction books about diplomacy": "كتب غير خيالية عن الدبلوماسية",
    "non-fiction books about dogs": "كتب غير خيالية عن الكلاب",
    "non-fiction books about drug traffickers": "كتب غير خيالية عن تجار مخدرات",
    "non-fiction books about drugs": "كتب غير خيالية عن عقاقير",
    "non-fiction books about elections": "كتب غير خيالية عن انتخابات",
    "non-fiction books about espionage": "كتب غير خيالية عن التجسس",
    "non-fiction books about gambling": "كتب غير خيالية عن مقامرة",
    "non-fiction books about gangs": "كتب غير خيالية عن عصابات",
    "non-fiction books about genocide": "كتب غير خيالية عن الإبادة الجماعية",
    "non-fiction books about godfather": "كتب غير خيالية عن العراب (فيلم)",
    "non-fiction books about gulag": "كتب غير خيالية عن غولاغ",
    "non-fiction books about immigration to europe": "كتب غير خيالية عن الهجرة إلى أوروبا",
    "non-fiction books about immigration to united states": "كتب غير خيالية عن الهجرة إلى الولايات المتحدة",
    "non-fiction books about immigration": "كتب غير خيالية عن الهجرة",
    "non-fiction books about indigenous peoples of americas": "كتب غير خيالية عن شعوب أصلية في الأمريكتين",
    "non-fiction books about italian-american culture": "كتب غير خيالية عن ثقافة أمريكية إيطالية",
    "non-fiction books about jack ripper": "كتب غير خيالية عن جاك السفاح",
    "non-fiction books about james bond": "كتب غير خيالية عن جيمس بوند",
    "non-fiction books about military history of united states": "كتب غير خيالية عن تاريخ الولايات المتحدة العسكري",
    "non-fiction books about mining": "كتب غير خيالية عن تعدين",
    "non-fiction books about murders in united states": "كتب غير خيالية عن جرائم قتل في الولايات المتحدة",
    "non-fiction books about murders": "كتب غير خيالية عن جرائم قتل",
    "non-fiction books about organized crime": "كتب غير خيالية عن جريمة منظمة",
    "non-fiction books about pablo escobar": "كتب غير خيالية عن بابلو إسكوبار",
    "non-fiction books about pornography": "كتب غير خيالية عن الإباحية",
    "non-fiction books about racism": "كتب غير خيالية عن عنصرية",
    "non-fiction books about richard ramirez": "كتب غير خيالية عن ريتشارد راميرز",
    "non-fiction books about royal air force": "كتب غير خيالية عن القوات الجوية الملكية",
    "non-fiction books about serial killers": "كتب غير خيالية عن قتلة متسلسلون",
    "non-fiction books about sexuality in christianity": "كتب غير خيالية عن الجنسانية في المسيحية",
    "non-fiction books about sexuality": "كتب غير خيالية عن الجنسانية",
    "non-fiction books about sicilian mafia": "كتب غير خيالية عن مافيا صقلية",
    "non-fiction books about slavery": "كتب غير خيالية عن العبودية",
    "non-fiction books about sudan": "كتب غير خيالية عن السودان",
    "non-fiction books about ted bundy": "كتب غير خيالية عن تيد بندي",
    "non-fiction books about theatre": "كتب غير خيالية عن المسرح",
    "non-fiction books about transport": "كتب غير خيالية عن نقل",
    "non-fiction books about turkey": "كتب غير خيالية عن تركيا",
    "non-fiction books about united states air force": "كتب غير خيالية عن القوات الجوية الأمريكية",
    "non-fiction books about united states navy": "كتب غير خيالية عن البحرية الأمريكية",
    "non-fiction books about unsolved murders in united states": "كتب غير خيالية عن جرائم قتل غير محلولة في الولايات المتحدة",
    "non-fiction books about unsolved murders": "كتب غير خيالية عن جرائم قتل غير محلولة",
    "non-fiction books about war": "كتب غير خيالية عن الحرب",
    "non-fiction books about women in war": "كتب غير خيالية عن المرأة في الحرب",
    "non-fiction books about women": "كتب غير خيالية عن المرأة",
    "non-fiction books adapted for other media": "كتب غير خيالية تم تحويلها إلى وسائط أخرى",
    "non-fiction books adapted into comics": "كتب غير خيالية تم تحويلها إلى قصص مصورة",
    "non-fiction books adapted into films": "كتب غير خيالية تم تحويلها إلى أفلام",
    "non-fiction books adapted into television shows": "كتب غير خيالية تم تحويلها إلى عروض تلفزيونية",
    "non-fiction books by country": "كتب غير خيالية حسب البلد",
    "non-fiction books by date": "كتب غير خيالية حسب التاريخ",
    "non-fiction books by decade": "كتب غير خيالية حسب العقد",
    "non-fiction books by gabriel garcía márquez": "كتب غير خيالية بواسطة غابرييل غارثيا ماركيث",
    "non-fiction books by h. p. lovecraft": "كتب غير خيالية بواسطة هوارد فيليبس لافكرافت",
    "non-fiction books by language": "كتب غير خيالية حسب اللغة",
    "non-fiction books by stephen king": "كتب غير خيالية بواسطة ستيفن كينغ",
    "non-fiction books by topic": "كتب غير خيالية حسب الموضوع",
    "non-fiction books by type": "كتب غير خيالية حسب الفئة",
    "non-fiction books by writer": "كتب غير خيالية حسب الكاتب",
    "non-fiction books by year": "كتب غير خيالية حسب السنة",
    "non-fiction books": "كتب غير خيالية",
    "non-fiction comic strips": "شرائط كومكس غير خيالية",
    "non-fiction comics": "قصص مصورة غير خيالية",
    "non-fiction crime writers": "كتاب جريمة غير روائيين",
    "non-fiction environmental writers": "كتاب بيئة غير روائيين",
    "non-fiction graphic novels": "روايات مصورة غير خيالية",
    "non-fiction novels about murders in united states": "روايات غير خيالية عن جرائم قتل في الولايات المتحدة",
    "non-fiction novels about murders": "روايات غير خيالية عن جرائم قتل",
    "non-fiction novels": "روايات غير خيالية",
    "non-fiction writers about organized crime in italy": "كتاب غير روائيين عن جريمة منظمة في إيطاليا",
    "non-fiction writers about organized crime in united states": "كتاب غير روائيين عن جريمة منظمة في الولايات المتحدة",
    "non-fiction writers about organized crime": "كتاب غير روائيين عن جريمة منظمة",
    "non-fiction writers by century and nationality": "كتاب غير روائيين حسب القرن والجنسية",
    "non-fiction writers by century": "كتاب غير روائيين حسب القرن",
    "non-fiction writers by ethnicity": "كتاب غير روائيين حسب المجموعة العرقية",
    "non-fiction writers by language": "كتاب غير روائيين حسب اللغة",
    "non-fiction writers by nationality and century": "كتاب غير روائيين حسب الجنسية والقرن",
    "non-fiction writers by nationality": "كتاب غير روائيين حسب الجنسية",
    "non-fiction writers from cornwall": "كتاب غير روائيين من كورنوال",
    "non-fiction writers from georgia (country)": "كتاب غير روائيين من جورجيا",
    "non-fiction writers from northern ireland by century": "كتاب غير روائيين من أيرلندا الشمالية حسب القرن",
    "non-fiction writers from ottoman empire": "كتاب غير روائيين من الدولة العثمانية",
    "non-fiction writers": "كتاب غير روائيين",
    "non-interventionism": "عدم التدخل",
    "non-interventionist parties": "أحزاب غير تدخلية",
    "non-metropolitan counties": "مقاطعات غير حضرية",
    "non-metropolitan districts of buckinghamshire": "ضواحي غير حضرية في باكينغهامشير",
    "non-metropolitan districts of cambridgeshire": "ضواحي غير حضرية في كامبريدجشير",
    "non-metropolitan districts of cumbria": "ضواحي غير حضرية في كمبريا",
    "non-metropolitan districts of derbyshire": "ضواحي غير حضرية في داربيشير",
    "non-metropolitan districts of devon": "ضواحي غير حضرية في ديفون",
    "non-metropolitan districts of dorset": "ضواحي غير حضرية في دورست",
    "non-metropolitan districts of east sussex": "ضواحي غير حضرية في شرق سوسكس",
    "non-metropolitan districts of essex": "ضواحي غير حضرية في إسكس",
    "non-metropolitan districts of gloucestershire": "ضواحي غير حضرية في غلوسترشير",
    "non-metropolitan districts of hampshire": "ضواحي غير حضرية في هامبشاير",
    "non-metropolitan districts of kent": "ضواحي غير حضرية في كنت",
    "non-metropolitan districts of lancashire": "ضواحي غير حضرية في لانكشير",
    "non-metropolitan districts of leicestershire": "ضواحي غير حضرية في ليسترشير",
    "non-metropolitan districts of lincolnshire": "ضواحي غير حضرية في لنكولنشاير",
    "non-metropolitan districts of norfolk": "ضواحي غير حضرية في نورفك",
    "non-metropolitan districts of north yorkshire": "ضواحي غير حضرية في شمال يوركشاير",
    "non-metropolitan districts of northamptonshire": "ضواحي غير حضرية في نورثهامبتونشاير",
    "non-metropolitan districts of nottinghamshire": "ضواحي غير حضرية في نوتنغهامشير",
    "non-metropolitan districts of oxfordshire": "ضواحي غير حضرية في أوكسفوردشاير",
    "non-metropolitan districts of somerset": "ضواحي غير حضرية في سومرست",
    "non-metropolitan districts of staffordshire": "ضواحي غير حضرية في ستافوردشاير",
    "non-metropolitan districts of suffolk": "ضواحي غير حضرية في سوفولك",
    "non-metropolitan districts of surrey": "ضواحي غير حضرية في سري",
    "non-metropolitan districts of warwickshire": "ضواحي غير حضرية في وركشير",
    "non-metropolitan districts of west sussex": "ضواحي غير حضرية في غرب ساسكس",
    "non-metropolitan districts of worcestershire": "ضواحي غير حضرية في رسيستيرشير",
    "non-metropolitan districts": "ضواحي غير حضرية",
    "non-narrative films": "أفلام غير سردية",
    "non-penetrative sex": "جنس خارجي",
    "non-profit organisations based in abu dhabi": "منظمات غير ربحية مقرها في أبو ظبي",
    "non-profit organisations based in afghanistan": "منظمات غير ربحية مقرها في أفغانستان",
    "non-profit organisations based in algeria": "منظمات غير ربحية مقرها في الجزائر",
    "non-profit organisations based in argentina": "منظمات غير ربحية مقرها في الأرجنتين",
    "non-profit organisations based in australia": "منظمات غير ربحية مقرها في أستراليا",
    "non-profit organisations based in australian capital territory": "منظمات غير ربحية مقرها في إقليم العاصمة الأسترالية",
    "non-profit organisations based in austria": "منظمات غير ربحية مقرها في النمسا",
    "non-profit organisations based in baden-württemberg": "منظمات غير ربحية مقرها في بادن-فورتمبيرغ",
    "non-profit organisations based in bahamas": "منظمات غير ربحية مقرها في باهاماس",
    "non-profit organisations based in bahrain": "منظمات غير ربحية مقرها في البحرين",
    "non-profit organisations based in bangladesh": "منظمات غير ربحية مقرها في بنغلاديش",
    "non-profit organisations based in barbados": "منظمات غير ربحية مقرها في بربادوس",
    "non-profit organisations based in bavaria": "منظمات غير ربحية مقرها في بافاريا",
    "non-profit organisations based in belgium": "منظمات غير ربحية مقرها في بلجيكا",
    "non-profit organisations based in belize": "منظمات غير ربحية مقرها في بليز",
    "non-profit organisations based in berlin": "منظمات غير ربحية مقرها في برلين",
    "non-profit organisations based in bhutan": "منظمات غير ربحية مقرها في بوتان",
    "non-profit organisations based in brazil": "منظمات غير ربحية مقرها في البرازيل",
    "non-profit organisations based in bremen (state)": "منظمات غير ربحية مقرها في ولاية بريمن",
    "non-profit organisations based in cambodia": "منظمات غير ربحية مقرها في كمبوديا",
    "non-profit organisations based in cayman islands": "منظمات غير ربحية مقرها في جزر كايمان",
    "non-profit organisations based in chile": "منظمات غير ربحية مقرها في تشيلي",
    "non-profit organisations based in colombia": "منظمات غير ربحية مقرها في كولومبيا",
    "non-profit organisations based in copenhagen": "منظمات غير ربحية مقرها في كوبنهاغن",
    "non-profit organisations based in cyprus": "منظمات غير ربحية مقرها في قبرص",
    "non-profit organisations based in democratic republic of congo": "منظمات غير ربحية مقرها في جمهورية الكونغو الديمقراطية",
    "non-profit organisations based in denmark": "منظمات غير ربحية مقرها في الدنمارك",
    "non-profit organisations based in ecuador": "منظمات غير ربحية مقرها في الإكوادور",
    "non-profit organisations based in egypt": "منظمات غير ربحية مقرها في مصر",
    "non-profit organisations based in england": "منظمات غير ربحية مقرها في إنجلترا",
    "non-profit organisations based in estonia": "منظمات غير ربحية مقرها في إستونيا",
    "non-profit organisations based in finland": "منظمات غير ربحية مقرها في فنلندا",
    "non-profit organisations based in france": "منظمات غير ربحية مقرها في فرنسا",
    "non-profit organisations based in germany": "منظمات غير ربحية مقرها في ألمانيا",
    "non-profit organisations based in ghana": "منظمات غير ربحية مقرها في غانا",
    "non-profit organisations based in hamburg": "منظمات غير ربحية مقرها في هامبورغ",
    "non-profit organisations based in hesse": "منظمات غير ربحية مقرها في هسن",
    "non-profit organisations based in hong kong": "منظمات غير ربحية مقرها في هونغ كونغ",
    "non-profit organisations based in hungary": "منظمات غير ربحية مقرها في المجر",
    "non-profit organisations based in india": "منظمات غير ربحية مقرها في الهند",
    "non-profit organisations based in iran": "منظمات غير ربحية مقرها في إيران",
    "non-profit organisations based in ireland": "منظمات غير ربحية مقرها في أيرلندا",
    "non-profit organisations based in italy": "منظمات غير ربحية مقرها في إيطاليا",
    "non-profit organisations based in jamaica": "منظمات غير ربحية مقرها في جامايكا",
    "non-profit organisations based in jersey": "منظمات غير ربحية مقرها في جيرزي",
    "non-profit organisations based in jordan": "منظمات غير ربحية مقرها في الأردن",
    "non-profit organisations based in karachi": "منظمات غير ربحية مقرها في كراتشي",
    "non-profit organisations based in kenya": "منظمات غير ربحية مقرها في كينيا",
    "non-profit organisations based in kosovo": "منظمات غير ربحية مقرها في كوسوفو",
    "non-profit organisations based in lahore": "منظمات غير ربحية مقرها في لاهور",
    "non-profit organisations based in latvia": "منظمات غير ربحية مقرها في لاتفيا",
    "non-profit organisations based in lebanon": "منظمات غير ربحية مقرها في لبنان",
    "non-profit organisations based in london": "منظمات غير ربحية مقرها في لندن",
    "non-profit organisations based in lower saxony": "منظمات غير ربحية مقرها في سكسونيا السفلى",
    "non-profit organisations based in luxembourg": "منظمات غير ربحية مقرها في لوكسمبورغ",
    "non-profit organisations based in madagascar": "منظمات غير ربحية مقرها في مدغشقر",
    "non-profit organisations based in malaysia": "منظمات غير ربحية مقرها في ماليزيا",
    "non-profit organisations based in maldives": "منظمات غير ربحية مقرها في جزر المالديف",
    "non-profit organisations based in mecklenburg-vorpommern": "منظمات غير ربحية مقرها في مكلنبورغ فوربومرن",
    "non-profit organisations based in moldova": "منظمات غير ربحية مقرها في مولدوفا",
    "non-profit organisations based in myanmar": "منظمات غير ربحية مقرها في ميانمار",
    "non-profit organisations based in namibia": "منظمات غير ربحية مقرها في ناميبيا",
    "non-profit organisations based in nepal": "منظمات غير ربحية مقرها في نيبال",
    "non-profit organisations based in netherlands": "منظمات غير ربحية مقرها في هولندا",
    "non-profit organisations based in new south wales": "منظمات غير ربحية مقرها في نيوساوث ويلز",
    "non-profit organisations based in new zealand": "منظمات غير ربحية مقرها في نيوزيلندا",
    "non-profit organisations based in north rhine-westphalia": "منظمات غير ربحية مقرها في شمال الراين-وستفاليا",
    "non-profit organisations based in northern ireland": "منظمات غير ربحية مقرها في أيرلندا الشمالية",
    "non-profit organisations based in northern territory": "منظمات غير ربحية مقرها في الإقليم الشمالي",
    "non-profit organisations based in norway": "منظمات غير ربحية مقرها في النرويج",
    "non-profit organisations based in pakistan": "منظمات غير ربحية مقرها في باكستان",
    "non-profit organisations based in peru": "منظمات غير ربحية مقرها في بيرو",
    "non-profit organisations based in poland": "منظمات غير ربحية مقرها في بولندا",
    "non-profit organisations based in portugal": "منظمات غير ربحية مقرها في البرتغال",
    "non-profit organisations based in puntland": "منظمات غير ربحية مقرها في أرض البنط",
    "non-profit organisations based in qatar": "منظمات غير ربحية مقرها في قطر",
    "non-profit organisations based in queensland": "منظمات غير ربحية مقرها في كوينزلاند",
    "non-profit organisations based in republic of ireland": "منظمات غير ربحية مقرها في جمهورية أيرلندا",
    "non-profit organisations based in rhineland-palatinate": "منظمات غير ربحية مقرها في راينلند بالاتينات",
    "non-profit organisations based in saudi arabia": "منظمات غير ربحية مقرها في السعودية",
    "non-profit organisations based in saxony": "منظمات غير ربحية مقرها في ساكسونيا",
    "non-profit organisations based in saxony-anhalt": "منظمات غير ربحية مقرها في ساكسونيا أنهالت",
    "non-profit organisations based in schleswig-holstein": "منظمات غير ربحية مقرها في شليسفيغ هولشتاين",
    "non-profit organisations based in scotland": "منظمات غير ربحية مقرها في إسكتلندا",
    "non-profit organisations based in singapore": "منظمات غير ربحية مقرها في سنغافورة",
    "non-profit organisations based in slovakia": "منظمات غير ربحية مقرها في سلوفاكيا",
    "non-profit organisations based in solomon islands": "منظمات غير ربحية مقرها في جزر سليمان",
    "non-profit organisations based in somalia": "منظمات غير ربحية مقرها في الصومال",
    "non-profit organisations based in south africa": "منظمات غير ربحية مقرها في جنوب إفريقيا",
    "non-profit organisations based in south australia": "منظمات غير ربحية مقرها في جنوب أستراليا",
    "non-profit organisations based in spain": "منظمات غير ربحية مقرها في إسبانيا",
    "non-profit organisations based in sri lanka": "منظمات غير ربحية مقرها في سريلانكا",
    "non-profit organisations based in sudan": "منظمات غير ربحية مقرها في السودان",
    "non-profit organisations based in sweden": "منظمات غير ربحية مقرها في السويد",
    "non-profit organisations based in switzerland": "منظمات غير ربحية مقرها في سويسرا",
    "non-profit organisations based in syria": "منظمات غير ربحية مقرها في سوريا",
    "non-profit organisations based in tasmania": "منظمات غير ربحية مقرها في تسمانيا",
    "non-profit organisations based in togo": "منظمات غير ربحية مقرها في توغو",
    "non-profit organisations based in trinidad and tobago": "منظمات غير ربحية مقرها في ترينيداد وتوباغو",
    "non-profit organisations based in uganda": "منظمات غير ربحية مقرها في أوغندا",
    "non-profit organisations based in united arab emirates": "منظمات غير ربحية مقرها في الإمارات العربية المتحدة",
    "non-profit organisations based in united kingdom": "منظمات غير ربحية مقرها في المملكة المتحدة",
    "non-profit organisations based in wales": "منظمات غير ربحية مقرها في ويلز",
    "non-profit organisations based in western australia": "منظمات غير ربحية مقرها في أستراليا الغربية",
    "non-profit organisations based in zambia": "منظمات غير ربحية مقرها في زامبيا",
    "non-profit organizations based in africa by country": "منظمات غير ربحية مقرها في إفريقيا حسب البلد",
    "non-profit organizations based in africa": "منظمات غير ربحية مقرها في إفريقيا",
    "non-profit organizations based in alabama": "منظمات غير ربحية مقرها في ألاباما",
    "non-profit organizations based in alaska": "منظمات غير ربحية مقرها في ألاسكا",
    "non-profit organizations based in alberta": "منظمات غير ربحية مقرها في ألبرتا",
    "non-profit organizations based in arizona": "منظمات غير ربحية مقرها في أريزونا",
    "non-profit organizations based in arkansas": "منظمات غير ربحية مقرها في أركنساس",
    "non-profit organizations based in asia by country": "منظمات غير ربحية مقرها في آسيا حسب البلد",
    "non-profit organizations based in asia": "منظمات غير ربحية مقرها في آسيا",
    "non-profit organizations based in azerbaijan": "منظمات غير ربحية مقرها في أذربيجان",
    "non-profit organizations based in barrie": "منظمات غير ربحية مقرها في باري (أونتاريو)",
    "non-profit organizations based in belarus": "منظمات غير ربحية مقرها في روسيا البيضاء",
    "non-profit organizations based in bosnia and herzegovina": "منظمات غير ربحية مقرها في البوسنة والهرسك",
    "non-profit organizations based in boston": "منظمات غير ربحية مقرها في بوسطن",
    "non-profit organizations based in british columbia": "منظمات غير ربحية مقرها في كولومبيا البريطانية",
    "non-profit organizations based in bronx": "منظمات غير ربحية مقرها في ذا برونكس",
    "non-profit organizations based in brooklyn": "منظمات غير ربحية مقرها في بروكلين",
    "non-profit organizations based in bulgaria": "منظمات غير ربحية مقرها في بلغاريا",
    "non-profit organizations based in california": "منظمات غير ربحية مقرها في كاليفورنيا",
    "non-profit organizations based in canada by province or territory": "منظمات غير ربحية مقرها في كندا حسب المقاطعة أو الإقليم",
    "non-profit organizations based in canada": "منظمات غير ربحية مقرها في كندا",
    "non-profit organizations based in chicago": "منظمات غير ربحية مقرها في شيكاغو",
    "non-profit organizations based in china": "منظمات غير ربحية مقرها في الصين",
    "non-profit organizations based in cincinnati": "منظمات غير ربحية مقرها في سينسيناتي",
    "non-profit organizations based in colorado": "منظمات غير ربحية مقرها في كولورادو",
    "non-profit organizations based in connecticut": "منظمات غير ربحية مقرها في كونيتيكت",
    "non-profit organizations based in costa rica": "منظمات غير ربحية مقرها في كوستاريكا",
    "non-profit organizations based in croatia": "منظمات غير ربحية مقرها في كرواتيا",
    "non-profit organizations based in czech republic": "منظمات غير ربحية مقرها في التشيك",
    "non-profit organizations based in delaware": "منظمات غير ربحية مقرها في ديلاوير",
    "non-profit organizations based in el salvador": "منظمات غير ربحية مقرها في السلفادور",
    "non-profit organizations based in estonia": "منظمات غير ربحية مقرها في إستونيا",
    "non-profit organizations based in europe by country": "منظمات غير ربحية مقرها في أوروبا حسب البلد",
    "non-profit organizations based in europe": "منظمات غير ربحية مقرها في أوروبا",
    "non-profit organizations based in florida": "منظمات غير ربحية مقرها في فلوريدا",
    "non-profit organizations based in georgia (u.s. state)": "منظمات غير ربحية مقرها في ولاية جورجيا",
    "non-profit organizations based in greece": "منظمات غير ربحية مقرها في اليونان",
    "non-profit organizations based in guatemala": "منظمات غير ربحية مقرها في غواتيمالا",
    "non-profit organizations based in haiti": "منظمات غير ربحية مقرها في هايتي",
    "non-profit organizations based in hawaii": "منظمات غير ربحية مقرها في هاواي",
    "non-profit organizations based in houston": "منظمات غير ربحية مقرها في هيوستن",
    "non-profit organizations based in idaho": "منظمات غير ربحية مقرها في أيداهو",
    "non-profit organizations based in illinois": "منظمات غير ربحية مقرها في إلينوي",
    "non-profit organizations based in indiana": "منظمات غير ربحية مقرها في إنديانا",
    "non-profit organizations based in indianapolis": "منظمات غير ربحية مقرها في إنديانابوليس",
    "non-profit organizations based in indonesia": "منظمات غير ربحية مقرها في إندونيسيا",
    "non-profit organizations based in insular areas of united states": "منظمات غير ربحية مقرها في المناطق المعزولة في الولايات المتحدة",
    "non-profit organizations based in iowa": "منظمات غير ربحية مقرها في آيوا",
    "non-profit organizations based in iraq": "منظمات غير ربحية مقرها في العراق",
    "non-profit organizations based in israel": "منظمات غير ربحية مقرها في إسرائيل",
    "non-profit organizations based in japan": "منظمات غير ربحية مقرها في اليابان",
    "non-profit organizations based in kaduna": "منظمات غير ربحية مقرها في كادونا",
    "non-profit organizations based in kansas": "منظمات غير ربحية مقرها في كانساس",
    "non-profit organizations based in kazakhstan": "منظمات غير ربحية مقرها في كازاخستان",
    "non-profit organizations based in kentucky": "منظمات غير ربحية مقرها في كنتاكي",
    "non-profit organizations based in kuwait": "منظمات غير ربحية مقرها في الكويت",
    "non-profit organizations based in lagos": "منظمات غير ربحية مقرها في ولاية لاغوس",
    "non-profit organizations based in lithuania": "منظمات غير ربحية مقرها في ليتوانيا",
    "non-profit organizations based in los angeles": "منظمات غير ربحية مقرها في لوس أنجلوس",
    "non-profit organizations based in louisiana": "منظمات غير ربحية مقرها في لويزيانا",
    "non-profit organizations based in macau": "منظمات غير ربحية مقرها في ماكاو",
    "non-profit organizations based in maine": "منظمات غير ربحية مقرها في مين",
    "non-profit organizations based in manitoba": "منظمات غير ربحية مقرها في مانيتوبا",
    "non-profit organizations based in maryland": "منظمات غير ربحية مقرها في ماريلند",
    "non-profit organizations based in massachusetts": "منظمات غير ربحية مقرها في ماساتشوستس",
    "non-profit organizations based in mexico": "منظمات غير ربحية مقرها في المكسيك",
    "non-profit organizations based in michigan": "منظمات غير ربحية مقرها في ميشيغان",
    "non-profit organizations based in minnesota": "منظمات غير ربحية مقرها في منيسوتا",
    "non-profit organizations based in mississippi": "منظمات غير ربحية مقرها في مسيسيبي",
    "non-profit organizations based in missouri": "منظمات غير ربحية مقرها في ميزوري",
    "non-profit organizations based in mongolia": "منظمات غير ربحية مقرها في منغوليا",
    "non-profit organizations based in montana": "منظمات غير ربحية مقرها في مونتانا",
    "non-profit organizations based in montreal": "منظمات غير ربحية مقرها في مونتريال",
    "non-profit organizations based in morocco": "منظمات غير ربحية مقرها في المغرب",
    "non-profit organizations based in nebraska": "منظمات غير ربحية مقرها في نبراسكا",
    "non-profit organizations based in nevada": "منظمات غير ربحية مقرها في نيفادا",
    "non-profit organizations based in new brunswick": "منظمات غير ربحية مقرها في نيو برونزويك",
    "non-profit organizations based in new hampshire": "منظمات غير ربحية مقرها في نيوهامشير",
    "non-profit organizations based in new jersey": "منظمات غير ربحية مقرها في نيوجيرسي",
    "non-profit organizations based in new mexico": "منظمات غير ربحية مقرها في نيومكسيكو",
    "non-profit organizations based in new orleans": "منظمات غير ربحية مقرها في نيو أورلينز",
    "non-profit organizations based in new york (state)": "منظمات غير ربحية مقرها في ولاية نيويورك",
    "non-profit organizations based in new york city": "منظمات غير ربحية مقرها في مدينة نيويورك",
    "non-profit organizations based in newfoundland and labrador": "منظمات غير ربحية مقرها في نيوفاوندلاند واللابرادور",
    "non-profit organizations based in nigeria": "منظمات غير ربحية مقرها في نيجيريا",
    "non-profit organizations based in north america by country": "منظمات غير ربحية مقرها في أمريكا الشمالية حسب البلد",
    "non-profit organizations based in north america": "منظمات غير ربحية مقرها في أمريكا الشمالية",
    "non-profit organizations based in north carolina": "منظمات غير ربحية مقرها في كارولاينا الشمالية",
    "non-profit organizations based in north dakota": "منظمات غير ربحية مقرها في داكوتا الشمالية",
    "non-profit organizations based in north macedonia": "منظمات غير ربحية مقرها في مقدونيا الشمالية",
    "non-profit organizations based in nova scotia": "منظمات غير ربحية مقرها في نوفا سكوشا",
    "non-profit organizations based in oceania": "منظمات غير ربحية مقرها في أوقيانوسيا",
    "non-profit organizations based in ohio": "منظمات غير ربحية مقرها في أوهايو",
    "non-profit organizations based in oklahoma": "منظمات غير ربحية مقرها في أوكلاهوما",
    "non-profit organizations based in ontario": "منظمات غير ربحية مقرها في أونتاريو",
    "non-profit organizations based in oregon": "منظمات غير ربحية مقرها في أوريغن",
    "non-profit organizations based in ottawa": "منظمات غير ربحية مقرها في أوتاوا",
    "non-profit organizations based in palestine": "منظمات غير ربحية مقرها في فلسطين",
    "non-profit organizations based in panama": "منظمات غير ربحية مقرها في بنما",
    "non-profit organizations based in pennsylvania": "منظمات غير ربحية مقرها في بنسلفانيا",
    "non-profit organizations based in philadelphia": "منظمات غير ربحية مقرها في فيلادلفيا",
    "non-profit organizations based in philippines": "منظمات غير ربحية مقرها في الفلبين",
    "non-profit organizations based in pittsburgh": "منظمات غير ربحية مقرها في بيتسبرغ",
    "non-profit organizations based in prince edward island": "منظمات غير ربحية مقرها في جزيرة الأمير إدوارد",
    "non-profit organizations based in puerto rico": "منظمات غير ربحية مقرها في بورتوريكو",
    "non-profit organizations based in quebec": "منظمات غير ربحية مقرها في كيبك",
    "non-profit organizations based in rhode island": "منظمات غير ربحية مقرها في رود آيلاند",
    "non-profit organizations based in romania": "منظمات غير ربحية مقرها في رومانيا",
    "non-profit organizations based in russia": "منظمات غير ربحية مقرها في روسيا",
    "non-profit organizations based in san diego": "منظمات غير ربحية مقرها في سان دييغو",
    "non-profit organizations based in san francisco bay area": "منظمات غير ربحية مقرها في منطقة خليج سان فرانسيسكو",
    "non-profit organizations based in san francisco": "منظمات غير ربحية مقرها في سان فرانسيسكو",
    "non-profit organizations based in saskatchewan": "منظمات غير ربحية مقرها في ساسكاتشوان",
    "non-profit organizations based in seattle": "منظمات غير ربحية مقرها في سياتل",
    "non-profit organizations based in serbia": "منظمات غير ربحية مقرها في صربيا",
    "non-profit organizations based in slovenia": "منظمات غير ربحية مقرها في سلوفينيا",
    "non-profit organizations based in south america": "منظمات غير ربحية مقرها في أمريكا الجنوبية",
    "non-profit organizations based in south carolina": "منظمات غير ربحية مقرها في كارولاينا الجنوبية",
    "non-profit organizations based in south dakota": "منظمات غير ربحية مقرها في داكوتا الجنوبية",
    "non-profit organizations based in south korea": "منظمات غير ربحية مقرها في كوريا الجنوبية",
    "non-profit organizations based in soviet union": "منظمات غير ربحية مقرها في الاتحاد السوفيتي",
    "non-profit organizations based in st. louis": "منظمات غير ربحية مقرها في سينت لويس",
    "non-profit organizations based in taiwan": "منظمات غير ربحية مقرها في تايوان",
    "non-profit organizations based in tennessee": "منظمات غير ربحية مقرها في تينيسي",
    "non-profit organizations based in texas": "منظمات غير ربحية مقرها في تكساس",
    "non-profit organizations based in thailand": "منظمات غير ربحية مقرها في تايلاند",
    "non-profit organizations based in toronto": "منظمات غير ربحية مقرها في تورونتو",
    "non-profit organizations based in turkey": "منظمات غير ربحية مقرها في تركيا",
    "non-profit organizations based in ukraine": "منظمات غير ربحية مقرها في أوكرانيا",
    "non-profit organizations based in united states by city": "منظمات غير ربحية مقرها في الولايات المتحدة حسب المدينة",
    "non-profit organizations based in united states by state or territory": "منظمات غير ربحية مقرها في الولايات المتحدة حسب الولاية أو الإقليم",
    "non-profit organizations based in united states": "منظمات غير ربحية مقرها في الولايات المتحدة",
    "non-profit organizations based in uruguay": "منظمات غير ربحية مقرها في أوروغواي",
    "non-profit organizations based in utah": "منظمات غير ربحية مقرها في يوتا",
    "non-profit organizations based in vancouver": "منظمات غير ربحية مقرها في فانكوفر",
    "non-profit organizations based in venezuela": "منظمات غير ربحية مقرها في فنزويلا",
    "non-profit organizations based in vermont": "منظمات غير ربحية مقرها في فيرمونت",
    "non-profit organizations based in vietnam": "منظمات غير ربحية مقرها في فيتنام",
    "non-profit organizations based in virginia": "منظمات غير ربحية مقرها في فرجينيا",
    "non-profit organizations based in washington (state)": "منظمات غير ربحية مقرها في ولاية واشنطن",
    "non-profit organizations based in west virginia": "منظمات غير ربحية مقرها في فرجينيا الغربية",
    "non-profit organizations based in wisconsin": "منظمات غير ربحية مقرها في ويسكونسن",
    "non-profit organizations based in wyoming": "منظمات غير ربحية مقرها في وايومنغ",
    "non-profit organizations": "منظمات غير ربحية",
    "non-profit publishers": "ناشرون غير ربحيون",
    "non-profit technology": "تقانة العمل الخيري",
    "non-renewable energy companies": "شركات طاقة غير متجددة",
    "non-renewable resource companies by century of disestablishment": "شركات موارد غير متجددة حسب قرن الانحلال",
    "non-renewable resource companies by century of establishment": "شركات موارد غير متجددة حسب قرن التأسيس",
    "non-renewable resource companies by year of disestablishment": "شركات موارد غير متجددة حسب سنة الانحلال",
    "non-renewable resource companies by year of establishment": "شركات موارد غير متجددة حسب سنة التأسيس",
    "non-renewable resource companies disestablished in 1550": "شركات موارد غير متجددة انحلت في 1550",
    "non-renewable resource companies disestablished in 20th century": "شركات موارد غير متجددة انحلت في القرن 20",
    "non-renewable resource companies established in 1550": "شركات موارد غير متجددة أسست في 1550",
    "non-renewable resource companies established in 20th century": "شركات موارد غير متجددة أسست في القرن 20",
    "non-renewable resource companies": "شركات موارد غير متجددة",
    "non-sufficient funds": "شيك مردود",
    "non-volatile memory": "الذاكرة المستاديمة",
    "non-volatile random-access memory": "ذاكرة الوصول العشوائي غير المتطايرة",
    "norwegian male non-fiction writers": "كتاب غير روائيين ذكور نرويجيون",
    "norwegian non-fiction books": "كتب نرويجية غير خيالية",
    "norwegian non-fiction writers by century": "كتاب غير روائيين نرويجيون حسب القرن",
    "norwegian non-fiction writers": "كتاب غير روائيين نرويجيون",
    "norwegian women non-fiction writers": "كاتبات غير روائيات نرويجيات",
    "pakistani male non-fiction writers": "كتاب غير روائيين ذكور باكستانيون",
    "pakistani non-fiction books": "كتب باكستانية غير خيالية",
    "pakistani non-fiction writers": "كتاب غير روائيين باكستانيون",
    "pakistani women non-fiction writers": "كاتبات غير روائيات باكستانيات",
    "palestinian male non-fiction writers": "كتاب غير روائيين ذكور فلسطينيون",
    "palestinian non-fiction writers": "كتاب غير روائيين فلسطينيون",
    "palestinian women non-fiction writers": "كاتبات غير روائيات فلسطينيات",
    "panamanian non-fiction writers": "كتاب غير روائيين بنميون",
    "paraguayan non-fiction writers": "كتاب غير روائيين بارغوايانيون",
    "peruvian male non-fiction writers": "كتاب غير روائيين ذكور بيرويون",
    "peruvian non-fiction books": "كتب بيروية غير خيالية",
    "peruvian non-fiction writers": "كتاب غير روائيين بيرويون",
    "polish male non-fiction writers": "كتاب غير روائيين ذكور بولنديون",
    "polish non-fiction books": "كتب بولندية غير خيالية",
    "polish non-fiction writers": "كتاب غير روائيين بولنديون",
    "polish women non-fiction writers": "كاتبات غير روائيات بولنديات",
    "portuguese male non-fiction writers": "كتاب غير روائيين ذكور برتغاليون",
    "portuguese non-fiction books": "كتب برتغالية غير خيالية",
    "portuguese non-fiction writers by century": "كتاب غير روائيين برتغاليون حسب القرن",
    "portuguese non-fiction writers": "كتاب غير روائيين برتغاليون",
    "portuguese women non-fiction writers": "كاتبات غير روائيات برتغاليات",
    "puerto rican male non-fiction writers": "كتاب غير روائيين ذكور بورتوريكيون",
    "puerto rican non-fiction writers by century": "كتاب غير روائيين بورتوريكيون حسب القرن",
    "puerto rican non-fiction writers": "كتاب غير روائيين بورتوريكيون",
    "puerto rican women non-fiction writers": "كاتبات غير روائيات بورتوريكيات",
    "qatari non-fiction writers": "كتاب غير روائيين قطريون",
    "romanian male non-fiction writers": "كتاب غير روائيين ذكور رومان",
    "romanian non-fiction writers": "كتاب غير روائيين رومان",
    "romanian women non-fiction writers": "كاتبات غير روائيات رومانيات",
    "russian male non-fiction writers": "كتاب غير روائيين ذكور روس",
    "russian non-fiction books": "كتب روسية غير خيالية",
    "russian non-fiction writers by century": "كتاب غير روائيين روس حسب القرن",
    "russian non-fiction writers": "كتاب غير روائيين روس",
    "russian women non-fiction writers": "كاتبات غير روائيات روسيات",
    "rwandan non-fiction writers": "كتاب غير روائيين روانديون",
    "sahrawi non-fiction writers": "كتاب غير روائيين صحراويون",
    "salvadoran non-fiction writers": "كتاب غير روائيين سلفادوريون",
    "samoan non-fiction writers": "كتاب غير روائيين سامويون",
    "saudi arabian non-fiction writers": "كتاب غير روائيين سعوديون",
    "scottish male non-fiction writers": "كتاب غير روائيين ذكور إسكتلنديون",
    "scottish non-fiction books": "كتب إسكتلندية غير خيالية",
    "scottish non-fiction writers by century": "كتاب غير روائيين إسكتلنديون حسب القرن",
    "scottish non-fiction writers": "كتاب غير روائيين إسكتلنديون",
    "scottish women non-fiction writers": "كاتبات غير روائيات إسكتلنديات",
    "senegalese non-fiction writers": "كتاب غير روائيين سنغاليون",
    "serbian male non-fiction writers": "كتاب غير روائيين ذكور صرب",
    "serbian non-fiction writers": "كتاب غير روائيين صرب",
    "serbian women non-fiction writers": "كاتبات غير روائيات صربيات",
    "series of non-fiction books": "سلسلات كتب غير خيالية",
    "sierra leonean non-fiction writers": "كتاب غير روائيين سيراليونيون",
    "singaporean non-fiction writers": "كتاب غير روائيين سنغافوريون",
    "slovak non-fiction writers": "كتاب غير روائيين سلوفاكيون",
    "slovenian non-fiction books": "كتب سلوفينية غير خيالية",
    "slovenian non-fiction writers": "كتاب غير روائيين سلوفينيون",
    "somalian non-fiction writers": "كتاب غير روائيين صوماليون",
    "south korean non-fiction writers": "كتاب غير روائيين كوريون جنوبيون",
    "south korean women non-fiction writers": "كاتبات غير روائيات كوريات جنوبيات",
    "soviet male non-fiction writers": "كتاب غير روائيين ذكور سوفيت",
    "soviet non-fiction writers": "كتاب غير روائيين سوفيت",
    "spanish male non-fiction writers": "كتاب غير روائيين ذكور إسبان",
    "spanish non-fiction books": "كتب إسبانية غير خيالية",
    "spanish non-fiction writers by century": "كتاب غير روائيين إسبان حسب القرن",
    "spanish non-fiction writers": "كتاب غير روائيين إسبان",
    "spanish women non-fiction writers": "كاتبات غير روائيات إسبانيات",
    "sports non-profit organizations": "منظمات غير ربحية رياضية",
    "sri lankan non-fiction writers": "كتاب غير روائيين سريلانكيون",
    "sudanese non-fiction writers": "كتاب غير روائيين سودانيون",
    "swedish male non-fiction writers": "كتاب غير روائيين ذكور سويديون",
    "swedish non-fiction books": "كتب سويدية غير خيالية",
    "swedish non-fiction writers by century": "كتاب غير روائيين سويديون حسب القرن",
    "swedish non-fiction writers": "كتاب غير روائيين سويديون",
    "swedish women non-fiction writers": "كاتبات غير روائيات سويديات",
    "swiss male non-fiction writers": "كتاب غير روائيين ذكور سويسريون",
    "swiss non-fiction books": "كتب سويسرية غير خيالية",
    "swiss non-fiction writers by century": "كتاب غير روائيين سويسريون حسب القرن",
    "swiss non-fiction writers": "كتاب غير روائيين سويسريون",
    "swiss women non-fiction writers": "كاتبات غير روائيات سويسريات",
    "syrian non-fiction books": "كتب سورية غير خيالية",
    "syrian non-fiction writers": "كتاب غير روائيين سوريون",
    "taiwanese non-fiction writers": "كتاب غير روائيين تايوانيون",
    "tajikistani non-fiction writers": "كتاب غير روائيين طاجيك",
    "tanzanian non-fiction writers": "كتاب غير روائيين تنزانيون",
    "television shows based on non-fiction books": "عروض تلفزيونية مبنية على كتب غير خيالية",
    "thai male non-fiction writers": "كتاب غير روائيين ذكور تايلنديون",
    "thai non-fiction books": "كتب تايلندية غير خيالية",
    "thai non-fiction writers": "كتاب غير روائيين تايلنديون",
    "togolese non-fiction writers": "كتاب غير روائيين توغويون",
    "trinidad and tobago male non-fiction writers": "كتاب غير روائيين ذكور ترنيداديون",
    "trinidad and tobago non-fiction writers": "كتاب غير روائيين ترنيداديون",
    "tunisian non-fiction writers": "كتاب غير روائيين تونسيون",
    "turkish cypriot non-fiction writers": "كتاب غير روائيين قبرصيون شماليون",
    "turkish male non-fiction writers": "كتاب غير روائيين ذكور أتراك",
    "turkish non-fiction books": "كتب تركية غير خيالية",
    "turkish non-fiction writers by century": "كتاب غير روائيين أتراك حسب القرن",
    "turkish non-fiction writers": "كتاب غير روائيين أتراك",
    "turkish women non-fiction writers": "كاتبات غير روائيات تركيات",
    "ugandan non-fiction books": "كتب أوغندية غير خيالية",
    "ugandan non-fiction writers": "كتاب غير روائيين أوغنديون",
    "ukrainian non-fiction books": "كتب أوكرانية غير خيالية",
    "ukrainian non-fiction writers": "كتاب غير روائيين أوكرانيون",
    "ukrainian women non-fiction writers": "كاتبات غير روائيات أوكرانيات",
    "uruguayan non-fiction books": "كتب أوروغويانية غير خيالية",
    "uruguayan non-fiction writers": "كتاب غير روائيين أوروغويانيون",
    "venezuelan non-fiction writers": "كتاب غير روائيين فنزويليون",
    "vietnamese non-fiction writers": "كتاب غير روائيين فيتناميون",
    "welsh male non-fiction writers": "كتاب غير روائيين ذكور ويلزيون",
    "welsh non-fiction books": "كتب ويلزية غير خيالية",
    "welsh non-fiction writers by century": "كتاب غير روائيين ويلزيون حسب القرن",
    "welsh non-fiction writers": "كتاب غير روائيين ويلزيون",
    "welsh women non-fiction writers": "كاتبات غير روائيات ويلزيات",
    "women non-fiction writers by nationality": "كاتبات غير روائيات حسب الجنسية",
    "women non-fiction writers from northern ireland": "كاتبات غير روائيات من أيرلندا الشمالية",
    "women non-fiction writers": "كاتبات غير روائيات",
    "works based on non-fiction books": "أعمال مبنية على كتب غير خيالية",
    "yemeni non-fiction writers": "كتاب غير روائيين يمنيون",
    "yugoslav non-fiction writers": "كتاب غير روائيين يوغسلافيون",
    "zambian non-fiction writers": "كتاب غير روائيين زامبيون",
    "zimbabwean non-fiction writers": "كتاب غير روائيين زيمبابويون",
}

non_fiction = {
    "non-fiction television shows": "عروض تلفزيونية غير خيالية",
}

data_series = {
    "american non-fiction television series": "مسلسلات تلفزيونية غير خيالية أمريكية",
    "american non-fiction web series": "مسلسلات ويب غير خيالية أمريكية",
    "australian non-fiction television series": "مسلسلات تلفزيونية غير خيالية أسترالية",
    "australian non-fiction web series": "مسلسلات ويب غير خيالية أسترالية",
    "british non-fiction television series": "مسلسلات تلفزيونية غير خيالية بريطانية",
    "british non-fiction web series": "مسلسلات ويب غير خيالية بريطانية",
    "bulgarian non-fiction television series": "مسلسلات تلفزيونية غير خيالية بلغارية",
    "canadian non-fiction web series": "مسلسلات ويب غير خيالية كندية",
    "finnish non-fiction television series": "مسلسلات تلفزيونية غير خيالية فنلندية",
    "non-fiction television series by country": "مسلسلات تلفزيونية غير خيالية حسب البلد",
    "non-fiction television series": "مسلسلات تلفزيونية غير خيالية",
    "non-fiction web series": "مسلسلات ويب غير خيالية",
    "taiwanese non-fiction television series": "مسلسلات تلفزيونية غير خيالية تايوانية",
}

to_test = [
    ("test_non", data1),
    ("test_non_fiction", non_fiction),
    ("test_data_series", data_series),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.slow
def test_non(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_series.items(), ids=data_series.keys())
@pytest.mark.slow
def test_data_series(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)



"""
Integration tests for the get_and_label function in labels_country module.
Tests the function directly with real data (without the full resolve pipeline).
"""

from __future__ import annotations

import pytest

from ArWikiCats.translations.funcs import get_and_label

integration_data = {
    "Hong Kong and Macao": "هونغ كونغ وماكاو",
    "Labuan and Sarawak": "لابوان وساراواك",
    "Nova Scotia and Prince Edward Island": "نوفا سكوشا وجزيرة الأمير إدوارد",
    "Rwanda and Burundi": "رواندا وبوروندي",
    "Roman Republic and Roman Empire": "الجمهورية الرومانية والإمبراطورية الرومانية",
    "qatar and yemen": "قطر واليمن",
}


@pytest.mark.integration
@pytest.mark.parametrize("category,expected", integration_data.items(), ids=integration_data.keys())
def test_get_and_label_integration(category: str, expected: str) -> None:
    """Test get_and_label with real data for joined country/region names."""
    label = get_and_label(category)
    assert label == expected



#
import pytest

from ArWikiCats import resolve_label_ar

examples = {
    "20th-century Albanian sports coaches": "مدربو رياضة ألبان في القرن 20",
    "19th-century actors": "ممثلون في القرن 19",
    "2000s American films": "أفلام أمريكية في عقد 2000",
    "2017 American television series debuts": "مسلسلات تلفزيونية أمريكية بدأ عرضها في 2017",
    "2017 American television series endings": "مسلسلات تلفزيونية أمريكية انتهت في 2017",
    "19th-century actors by religion": "ممثلون في القرن 19 حسب الدين",
    "19th-century people by religion": "أشخاص في القرن 19 حسب الدين",
}

TEMPORAL_CASES = [
    ("temporal_1", examples),
]


@pytest.mark.parametrize("category, expected", examples.items(), ids=examples.keys())
def test_add_in(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected



#!/usr/bin/python3
"""Bot module for population and label lookups from 2018 data.

This module provides functionality to look up Arabic labels for categories
using population data from 2018 and other mapping tables.
"""

import functools
import logging

from ...new_resolvers import all_new_resolvers
from ...new_resolvers.bys_new import resolve_by_labels
from ...translations.funcs import _get_from_alias, open_json_file

logger = logging.getLogger(__name__)

pop_All_2018 = open_json_file("population/pop_All_2018.json")  # 524266

pop_All_2018.update(
    {
        "establishments": "تأسيسات",
        "disestablishments": "انحلالات",
    }
)

first_data = {
    "by country": "حسب البلد",
    "in": "في",
    "films": "أفلام",
    "decades": "عقود",
    "women": "المرأة",
    "women in": "المرأة في",
    "medalists": "فائزون بميداليات",
    "gold medalists": "فائزون بميداليات ذهبية",
    "silver medalists": "فائزون بميداليات فضية",
    "bronze medalists": "فائزون بميداليات برونزية",
    "kingdom of": "مملكة",
    "kingdom-of": "مملكة",
    "country": "البلد",
}


@functools.lru_cache(maxsize=10000)
def _get_pop_All_18(key: str, default: str = "") -> str:
    """
    Retrieve the Arabic label for a key from the in-memory 2018 population mapping.

    Parameters:
        key (str): Lookup key to search in the mapping.
        default (str): Value to return if the key is not present.

    Returns:
        str: The label mapped to `key`, or `default` if no mapping exists.
    """
    result = pop_All_2018.get(key, default)
    return result


@functools.lru_cache(maxsize=10000)
def get_pop_all_18_wrap(key: str, default: str = "") -> str:
    """
    Resolve an Arabic population or category label for a given key using layered lookup sources.

    Parameters:
        key (str): Lookup key; a leading "the " is ignored.
        default (str): Value returned when no label is found.

    Returns:
        str: The found Arabic label, or `default` if no match is found.
    """
    result = first_data.get(key.lower(), "") or ""

    if result:
        return result

    key = key.removeprefix("the ")

    call_ables = {
        "all_new_resolvers": all_new_resolvers,
        "_get_pop_All_18": _get_pop_All_18,
        "resolve_by_labels": resolve_by_labels,
        "_get_from_alias": _get_from_alias,
    }

    for name, func in call_ables.items():
        result = func(key)
        if result:
            logger.debug(f"get_pop_All_18: Found key in {name}: {key} -> {result}")
            return result

    return default


@functools.lru_cache(maxsize=10000)
def get_pop_All_18(key: str, default: str = "") -> str:
    """
    Lookup an Arabic label for `key` using layered 2018 population and alias sources.

    If no label is found for `key` as given, the function retries once with hyphens replaced by spaces.

    Parameters:
        key (str): The lookup key or category name.
        default (str): Value to return when no label is found.

    Returns:
        str: The resolved label string if found, `default` otherwise.
    """
    result = get_pop_all_18_wrap(key, default)

    if not result and "-" in key:
        result = get_pop_all_18_wrap(key.replace("-", " "), default)

    return result



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

the_female_data = {
    "new zealand rugby league chairmen and investors": "رؤساء ومسيرو الدوري النيوزيلندي للرجبي",
    "welsh rugby league": "الدوري الويلزي للرجبي",
    "welsh rugby league chairmen and investors": "رؤساء ومسيرو الدوري الويلزي للرجبي",
    "welsh rugby union": "اتحاد الرجبي الويلزي",
    "welsh rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي الويلزي",
    "english rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي الإنجليزي",
    "french rugby union chairmen and investors": "رؤساء ومسيرو اتحاد الرجبي الفرنسي",
    "lithuanian basketball chairmen and investors": "رؤساء ومسيرو كرة السلة الليتوانية",
    "greek volleyball chairmen and investors": "رؤساء ومسيرو كرة الطائرة اليونانية",
    "greek basketball chairmen and investors": "رؤساء ومسيرو كرة السلة اليونانية",
    "saudiarabian football chairmen and investors": "رؤساء ومسيرو كرة القدم السعودية",
    # "saudi arabian football chairmen and investors": "رؤساء ومسيرو كرة القدم السعودية",
    "palestinian football chairmen and investors": "رؤساء ومسيرو كرة القدم الفلسطينية",
    "swiss football chairmen and investors": "رؤساء ومسيرو كرة القدم السويسرية",
    "egyptian football chairmen and investors": "رؤساء ومسيرو كرة القدم المصرية",
    "british football chairmen and investors": "رؤساء ومسيرو كرة القدم البريطانية",
    "new zealand association football chairmen and investors": "رؤساء ومسيرو كرة القدم النيوزيلندية",
    "paraguayan football chairmen and investors": "رؤساء ومسيرو كرة القدم البارغوايانية",
    "togolese football chairmen and investors": "رؤساء ومسيرو كرة القدم التوغوية",
    "uruguayan football chairmen and investors": "رؤساء ومسيرو كرة القدم الأوروغويانية",
    "russian football chairmen and investors": "رؤساء ومسيرو كرة القدم الروسية",
    "english football chairmen and investors": "رؤساء ومسيرو كرة القدم الإنجليزية",
    "emirati football chairmen and investors": "رؤساء ومسيرو كرة القدم الإماراتية",
    "filipino football chairmen and investors": "رؤساء ومسيرو كرة القدم الفلبينية",
    "indian football chairmen and investors": "رؤساء ومسيرو كرة القدم الهندية",
    "chinese football chairmen and investors": "رؤساء ومسيرو كرة القدم الصينية",
    "cypriot football chairmen and investors": "رؤساء ومسيرو كرة القدم القبرصية",
    "israeli football chairmen and investors": "رؤساء ومسيرو كرة القدم الإسرائيلية",
    "lithuanian football chairmen and investors": "رؤساء ومسيرو كرة القدم الليتوانية",
    "belgian football chairmen and investors": "رؤساء ومسيرو كرة القدم البلجيكية",
    "romanian football chairmen and investors": "رؤساء ومسيرو كرة القدم الرومانية",
    "italian football chairmen and investors": "رؤساء ومسيرو كرة القدم الإيطالية",
    "bahraini football chairmen and investors": "رؤساء ومسيرو كرة القدم البحرينية",
    "welsh football chairmen and investors": "رؤساء ومسيرو كرة القدم الويلزية",
    "iraqi football chairmen and investors": "رؤساء ومسيرو كرة القدم العراقية",
    "norwegian football chairmen and investors": "رؤساء ومسيرو كرة القدم النرويجية",
    "spanish football chairmen and investors": "رؤساء ومسيرو كرة القدم الإسبانية",
    "ghanaian football chairmen and investors": "رؤساء ومسيرو كرة القدم الغانية",
    "nigerian football chairmen and investors": "رؤساء ومسيرو كرة القدم النيجيرية",
    "french football chairmen and investors": "رؤساء ومسيرو كرة القدم الفرنسية",
    "argentine football chairmen and investors": "رؤساء ومسيرو كرة القدم الأرجنتينية",
    "danish football chairmen and investors": "رؤساء ومسيرو كرة القدم الدنماركية",
    "south korean football chairmen and investors": "رؤساء ومسيرو كرة القدم الكورية الجنوبية",
    "icelandic football chairmen and investors": "رؤساء ومسيرو كرة القدم الآيسلندية",
    "republic of ireland association football chairmen and investors": "رؤساء ومسيرو كرة القدم الأيرلندية",
    "latvian football chairmen and investors": "رؤساء ومسيرو كرة القدم اللاتفية",
    "greek football chairmen and investors": "رؤساء ومسيرو كرة القدم اليونانية",
    "serbian football chairmen and investors": "رؤساء ومسيرو كرة القدم الصربية",
    "iranian football chairmen and investors": "رؤساء ومسيرو كرة القدم الإيرانية",
    "bolivian football chairmen and investors": "رؤساء ومسيرو كرة القدم البوليفية",
    "australian soccer chairmen and investors": "رؤساء ومسيرو كرة القدم الأسترالية",
    "moroccan football chairmen and investors": "رؤساء ومسيرو كرة القدم المغربية",
    "austrian football chairmen and investors": "رؤساء ومسيرو كرة القدم النمساوية",
    "portuguese football chairmen and investors": "رؤساء ومسيرو كرة القدم البرتغالية",
    "czech football chairmen and investors": "رؤساء ومسيرو كرة القدم التشيكية",
    "thai football chairmen and investors": "رؤساء ومسيرو كرة القدم التايلندية",
    "singaporean football chairmen and investors": "رؤساء ومسيرو كرة القدم السنغافورية",
    "turkish football chairmen and investors": "رؤساء ومسيرو كرة القدم التركية",
    "indonesian football chairmen and investors": "رؤساء ومسيرو كرة القدم الإندونيسية",
    "qatari football chairmen and investors": "رؤساء ومسيرو كرة القدم القطرية",
    "brazilian football chairmen and investors": "رؤساء ومسيرو كرة القدم البرازيلية",
    "swedish football chairmen and investors": "رؤساء ومسيرو كرة القدم السويدية",
    "dutch football chairmen and investors": "رؤساء ومسيرو كرة القدم الهولندية",
    "american soccer chairmen and investors": "رؤساء ومسيرو كرة القدم الأمريكية",
    "german football chairmen and investors": "رؤساء ومسيرو كرة القدم الألمانية",
    "ukrainian football chairmen and investors": "رؤساء ومسيرو كرة القدم الأوكرانية",
    "japanese football chairmen and investors": "رؤساء ومسيرو كرة القدم اليابانية",
    "canadian soccer chairmen and investors": "رؤساء ومسيرو كرة القدم الكندية",
    "mexican football chairmen and investors": "رؤساء ومسيرو كرة القدم المكسيكية",
}

data6 = {
    "georgia (country) freestyle wrestling federation": "الاتحاد الجورجي للمصارعة الحرة",
    "philippine sailing (sport) federation": "الاتحاد الفلبيني لرياضة الإبحار",
}

ar_sport_team_data = {
    # "Yemeni football championships clubs": "أندية بطولة اليمن لكرة القدم",
    "british softball championshipszz": "بطولة المملكة المتحدة للكرة اللينة",
    "ladies british softball tour": "بطولة المملكة المتحدة للكرة اللينة للسيدات",
    "british football tour": "بطولة المملكة المتحدة لكرة القدم",
    "Yemeni football championships": "بطولة اليمن لكرة القدم",
    "german figure skating championships": "بطولة ألمانيا للتزلج الفني",
    "british figure skating championships": "بطولة المملكة المتحدة للتزلج الفني",
}


sport_jobs_female_data = {
    "dominican republic national football teams": "منتخبات كرة قدم وطنية دومينيكانية",
    "yemeni national softball teams": "منتخبات كرة لينة وطنية يمنية",
    "Women's National Basketball League": "الدوري الوطني لكرة السلة للسيدات",
    "northern ireland": "",
}


@pytest.mark.parametrize("category, expected_key", the_female_data.items(), ids=the_female_data.keys())
@pytest.mark.fast
def test_the_female_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", ar_sport_team_data.items(), ids=ar_sport_team_data.keys())
@pytest.mark.fast
def test_ar_sport_team_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", sport_jobs_female_data.items(), ids=sport_jobs_female_data.keys())
@pytest.mark.fast
def test_sport_jobs_female_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


TEMPORAL_CASES = [
    ("test_resolve_nats_sport_multi_v2", data6, resolve_nats_sport_multi_v2),
    ("test_ar_sport_team_data", ar_sport_team_data, resolve_nats_sport_multi_v2),
    ("test_sport_jobs_female_data", sport_jobs_female_data, resolve_nats_sport_multi_v2),
    ("test_sport_jobs_the_female_data", the_female_data, resolve_nats_sport_multi_v2),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=True)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
ArWikiCats: A package for processing and resolving Arabic Wikipedia category labels.

This library provides automatic translation of English Wikipedia category names to Arabic,
handling complex patterns including temporal (years, centuries), geographical (countries,
cities), occupational, and sports-related categories.

Version
-------
__version__ = "0.2.2"

Quick Start
-----------
Resolve a single category::

    from ArWikiCats import resolve_label_ar

    arabic_label = resolve_label_ar("British footballers")
    # Returns: 'لاعبو كرة قدم بريطانيون'

Batch processing::

    from ArWikiCats import batch_resolve_labels

    categories = ["British footballers", "French politicians", "2020 deaths"]
    result = batch_resolve_labels(categories)
    print(result.labels)  # Dict mapping categories to Arabic labels
    print(result.no_labels)  # List of unresolved categories

Using the EventProcessor::

    from ArWikiCats import EventProcessor

    processor = EventProcessor()
    processed = processor.process_single("American actors")
    print(processed.final_label)  # With "تصنيف:" prefix

Main Components
---------------
- resolve_label_ar: Single category resolution
- batch_resolve_labels: Batch processing with statistics
- EventProcessor: Full-featured processing engine
"""

from .event_processing import (
    EventProcessor,
    batch_resolve_labels,
    resolve_arabic_category_label,
)
from .helps.len_print import dump_all_len
from .helps.memory import print_memory
from .logging_config import setup_logging
from .main_processers.main_resolve import resolve_label_ar

setup_logging()

__version__ = "0.2.2"

__all__ = [
    "resolve_label_ar",
    "batch_resolve_labels",
    "resolve_arabic_category_label",
    "EventProcessor",
    "print_memory",
    "dump_all_len",
]



"""
Core data models for translation formatting.
This package contains the base classes and structures used for representing
and processing different translation patterns.
"""

from .model_data_v2_formater import MultiDataFormatterBaseV2
from .model_multi_data import (
    MultiDataFormatterBase,
    MultiDataFormatterBaseYear,
    MultiDataFormatterBaseYearV2,
)
from .model_multi_data_base import MultiDataFormatterBaseHelpers, NormalizeResult
from .model_multi_data_year_from import MultiDataFormatterYearAndFrom
from .model_multi_data_year_from_2 import MultiDataFormatterYearAndFrom2

__all__ = [
    "MultiDataFormatterBaseHelpers",
    "NormalizeResult",
    "MultiDataFormatterBase",
    "MultiDataFormatterBaseV2",
    "MultiDataFormatterBaseYear",
    "MultiDataFormatterBaseYearV2",
    "MultiDataFormatterYearAndFrom",
    "MultiDataFormatterYearAndFrom2",
]



"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data_callback

data_0 = {
    "1520 in men's football": "كرة قدم رجالية في 1520",
    "1550s in cycle racing": "سباق الدراجات في عقد 1550",
    "1550 in motorsport": "رياضة المحركات في 1550",
    "1520 in youth football": "كرة قدم شبابية في 1520",
    "Coaches of American football from West Virginia": "مدربو كرة القدم الأمريكية من فرجينيا الغربية",
}

data_1 = {
    "Soccer clubs in Papua New Guinea": "أندية كرة قدم في بابوا غينيا الجديدة",
    "Table tennis clubs": "أندية كرة طاولة",
    "volleyball clubs in italy": "أندية كرة طائرة في إيطاليا",
    "Wheelchair basketball leagues in Australia": "دوريات كرة سلة على كراسي متحركة في أستراليا",
    "Wheelchair basketball leagues in Europe": "دوريات كرة سلة على كراسي متحركة في أوروبا",
    "Wheelchair tennis tournaments": "بطولات كرة المضرب على الكراسي المتحركة",
    "Papua New Guinea in international cricket": "بابوا غينيا الجديدة في كريكت دولية",
    "Women's basketball in Papua New Guinea": "كرة سلة نسائية في بابوا غينيا الجديدة",
    "Women's soccer in Papua New Guinea": "كرة قدم نسائية في بابوا غينيا الجديدة",
    "Women's cricket in Papua New Guinea": "كريكت نسائية في بابوا غينيا الجديدة",
    "Tennis tournaments in Antigua and Barbuda": "بطولات كرة المضرب في أنتيغوا وباربودا",
    "Women's cricket in Antigua and Barbuda": "كريكت نسائية في أنتيغوا وباربودا",
    "Youth athletics": "ألعاب قوى شبابية",
    "Women's sports seasons by continent": "مواسم رياضات نسائية حسب القارة",
    "Documentary films about women's sports": "أفلام وثائقية عن رياضات نسائية",
    "History of women's sports": "تاريخ رياضات نسائية",
    "Women's sports in the United States by state": "رياضات نسائية في الولايات المتحدة حسب الولاية",
    "Works about women's sports": "أعمال عن رياضات نسائية",
    "women's sports leagues in uzbekistan": "دوريات رياضية نسائية في أوزبكستان",
    "Women's sports organizations in the United States": "منظمات رياضية نسائية في الولايات المتحدة",
    "Women's sports teams in Cuba": "فرق رياضية نسائية في كوبا",
    "Women's sports in United States by state": "رياضات نسائية في الولايات المتحدة حسب الولاية",
    "motorsport venues in massachusetts": "ملاعب رياضة المحركات في ماساتشوستس",
    "motorsport venues in scotland": "ملاعب رياضة المحركات في إسكتلندا",
    "women's cricket teams in india": "فرق كريكت نسائية في الهند",
    "women's football in slovakia": "كرة قدم نسائية في سلوفاكيا",
    "women's futsal in bolivia": "كرة صالات نسائية في بوليفيا",
    "tennis tournaments in serbia-and-montenegro": "بطولات كرة المضرب في صربيا والجبل الأسود",
    "men's football leagues in algeria": "دوريات كرة قدم رجالية في الجزائر",
    "basketball leagues in oceania": "دوريات كرة سلة في أوقيانوسيا",
}


@pytest.mark.parametrize("category, expected_key", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_new_data(category: str, expected_key: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected_key


to_test = [
    ("test_sports_new_1", data_0, resolve_label_ar),
    ("test_sports_new_2", data_1, resolve_label_ar),
]
test_dump_all = make_dump_test_name_data_callback(to_test, run_same=True)



import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

fast_data = {
    "basketball venues in serbia": "ملاعب كرة السلة في صربيا",
    "Cycle racing in Antigua and Barbuda": "سباق الدراجات في أنتيغوا وباربودا",
    "Cycling in Antigua and Barbuda": "سباق الدراجات الهوائية في أنتيغوا وباربودا",
    "Dance music groups from Northern Ireland": "مجموعات رقص موسيقية من أيرلندا الشمالية",
    "Lists of office-holders in 2014": "قوائم أصحاب مناصب في 2014",
    "Lists of office-holders in Armenia": "قوائم أصحاب مناصب في أرمينيا",
    "Lists of office-holders in Syria": "قوائم أصحاب مناصب في سوريا",
    "Motorsport in West Virginia": "رياضة المحركات في فرجينيا الغربية",
    "music based on actual events": "موسيقى مبنية على أحداث حقيقية",
    "Music organisations based in Antigua and Barbuda": "منظمات موسيقية مقرها في أنتيغوا وباربودا",
    "Native American history by state": "تاريخ أمريكي أصلي حسب الولاية",
    "Natural gas fields in Papua New Guinea": "حقول غاز طبيعي في بابوا غينيا الجديدة",
    "rugby union leagues in japan": "دوريات اتحاد رجبي في اليابان",
    "Running in Antigua and Barbuda": "الركض في أنتيغوا وباربودا",
    "Running in Papua New Guinea": "الركض في بابوا غينيا الجديدة",
    "Sports at the Summer Universiade": "رياضات في الألعاب الجامعية الصيفية",
    "sports by country": "رياضات حسب البلد",
    "sports by month": "رياضات حسب الشهر",
    "Sports in Alexandria, Virginia": "رياضات في الإسكندرية (فرجينيا)",
    "Sports in Clarksburg, West Virginia": "رياضات في كلاركسبورغ (فرجينيا الغربية)",
    "Sports in Fairfax, Virginia": "رياضات في فيرفاكس (فرجينيا)",
    "Sports in Martinsburg, West Virginia": "رياضات في مرتينسبورغ (فرجينيا الغربية)",
    "Sports in Parkersburg, West Virginia": "رياضات في باركرسبورغ (فرجينيا الغربية)",
    "Sports in Roanoke, Virginia": "رياضات في روانوك (فرجينيا)",
    "Sports in Westchester County, New York": "رياضات في مقاطعة ويستتشستر (نيويورك)",
    "Sports in Williamsburg, Virginia": "رياضات في ويليامزبرغ (فرجينيا)",
    "sports originating in pakistan": "رياضات نشأت في باكستان",
    "Commissioners for South Georgia and South Sandwich Islands": "مفوضين في جورجيا الجنوبية وجزر ساندويتش الجنوبية",
    "Founders of Norwegian schools and colleges": "مؤسسي مدارس وكليات نرويجية",
    "Golf tournaments in Guatemala": "بطولات الغولف في غواتيمالا",
    "Golf tournaments in Peru": "بطولات الغولف في بيرو",
    "Motorsport in North America": "رياضة المحركات في أمريكا الشمالية",
    "Motorsport in Tanzania": "رياضة المحركات في تنزانيا",
    "Music based on works by William Shakespeare": "موسيقى مبنية على أعمال وليم شكسبير",
    "Music by country subdivision": "موسيقى حسب تقسيم البلد",
    "Music organisations based in Democratic Republic of Congo": "منظمات موسيقية مقرها في جمهورية الكونغو الديمقراطية",
    "Music organisations based in Djibouti": "منظمات موسيقية مقرها في جيبوتي",
    "Music organisations based in Somalia": "منظمات موسيقية مقرها في الصومال",
    "Musical groups by time of reestablishment": "مجموعات موسيقية حسب وقت إعادة التأسيس",
    "Musical groups from Bern": "مجموعات موسيقية من برن",
    "Musical groups from Brussels": "مجموعات موسيقية من بروكسل",
    "Musical groups from County Clare": "مجموعات موسيقية من مقاطعة كلير",
    "Musical groups from Kiev": "مجموعات موسيقية من كييف",
    "Natural gas fields in China": "حقول غاز طبيعي في الصين",
    "Natural gas pipelines by country": "خطوط أنابيب غاز حسب البلد",
    "Olympic competitors for Russian Empire": "منافسون في الألعاب الأولمبية من الإمبراطورية الروسية",
    "Running in Gabon": "الركض في الغابون",
    "Running in Mozambique": "الركض في موزمبيق",
    "Running in Suriname": "الركض في سورينام",
    "Sports at Asian Youth Games": "رياضات في الألعاب الآسيوية الشبابية",
    "Sports in Bemidji, Minnesota": "رياضات في بيميدجي (منيسوتا)",
    "Sports in Duluth, Minnesota": "رياضات في دولوث",
    "Sports in Mankato, Minnesota": "رياضات في مانكاتو (منيسوتا)",
    "Sports in Newburgh, New York": "رياضات في نيوبورغ (نيويورك)",
    "Sports in Niagara Falls, New York": "رياضات في نياجارا فولز (نيويورك)",
    "Sports in Olympia, Washington": "رياضات في أولمبيا (واشنطن)",
    "Sports in Puerto Rico": "رياضات في بورتوريكو",
    "Sports in Rochester, Minnesota": "رياضات في روتشيستر (منيسوتا)",
    "Sports in St. Cloud, Minnesota": "رياضات في سانت كلاود (منيسوتا)",
    "Sports in Walla Walla, Washington": "رياضات في والا والا (واشنطن)",
    "Christian rock groups from Arizona": "فرق روك مسيحية من أريزونا",
    "Christian rock groups from California": "فرق روك مسيحية من كاليفورنيا",
    "Christian rock groups from Florida": "فرق روك مسيحية من فلوريدا",
    "Christian rock groups from Georgia (U.S. state)": "فرق روك مسيحية من ولاية جورجيا",
    "Christian rock groups from Illinois": "فرق روك مسيحية من إلينوي",
    "Christian rock groups from Iowa": "فرق روك مسيحية من آيوا",
    "Christian rock groups from Kentucky": "فرق روك مسيحية من كنتاكي",
    "Christian rock groups from Louisiana": "فرق روك مسيحية من لويزيانا",
    "Christian rock groups from Michigan": "فرق روك مسيحية من ميشيغان",
    "Christian rock groups from Minnesota": "فرق روك مسيحية من منيسوتا",
    "Christian rock groups from Ohio": "فرق روك مسيحية من أوهايو",
    "Christian rock groups from Oklahoma": "فرق روك مسيحية من أوكلاهوما",
    "Christian rock groups from South Carolina": "فرق روك مسيحية من كارولاينا الجنوبية",
    "Christian rock groups from Tennessee": "فرق روك مسيحية من تينيسي",
    "Christian rock groups from Texas": "فرق روك مسيحية من تكساس",
    "Christian rock groups from Washington (state)": "فرق روك مسيحية من ولاية واشنطن",
    "Christian rock groups from West Virginia": "فرق روك مسيحية من فرجينيا الغربية",
    "Cycling at Islamic Solidarity Games": "سباق الدراجات الهوائية في ألعاب التضامن الإسلامي",
    "Music based on works by Hans Christian Andersen": "موسيقى مبنية على أعمال هانس كريستيان أندرسن",
    "Sports at 2010 Islamic Solidarity Games": "رياضات في ألعاب التضامن الإسلامي 2010",
    "Sports at Islamic Solidarity Games": "رياضات في ألعاب التضامن الإسلامي",
    "1650s crimes": "جرائم عقد 1650",
    "1650s disasters": "كوارث عقد 1650",
    "1650s disestablishments": "انحلالات عقد 1650",
    "1650s establishments": "تأسيسات عقد 1650",
    "1st millennium bc establishments": "تأسيسات الألفية 1 ق م",
    "1st millennium disestablishments": "انحلالات الألفية 1",
    "20th century attacks": "هجمات القرن 20",
    "20th century clergy": "رجال دين في القرن 20",
    "20th century lawyers": "محامون في القرن 20",
    "20th century mathematicians": "رياضياتيون في القرن 20",
    "20th century north american people": "أمريكيون شماليون في القرن 20",
    "20th century norwegian people": "نرويجيون في القرن 20",
    "20th century people": "أشخاص في القرن 20",
    "20th century philosophers": "فلاسفة في القرن 20",
    "20th century photographers": "مصورون في القرن 20",
    "20th century roman catholic bishops": "أساقفة كاثوليك رومان في القرن 20",
    "20th century romanian people": "رومان في القرن 20",
    "march 1650 crimes": "جرائم مارس 1650",
    "september 1650 crimes": "جرائم سبتمبر 1650",
}


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_event2_fast(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    ("fast_data", fast_data),
]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)



#

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_skip = {
    "Antigua and Barbuda and the Commonwealth of Nations": "x",
    "Antigua and Barbuda articles by importance": "x",
    "Antigua and Barbuda articles by quality": "x",
    "Antigua and Barbuda at the Junior Pan American Games": "x",
    "Antigua and Barbuda aviation law": "x",
    "Antigua and Barbuda beauty pageant winners": "x",
    "Antigua and Barbuda calypsonians": "x",
    "Antigua and Barbuda court system": "x",
    "Antigua and Barbuda dressage riders": "x",
    "Antigua and Barbuda evangelicals": "x",
    "Antigua and Barbuda geography-related lists": "x",
    "Antigua and Barbuda judges on the courts of Anguilla": "x",
    "Antigua and Barbuda judges on the courts of Belize": "x",
    "Antigua and Barbuda judges on the courts of Grenada": "x",
    "Antigua and Barbuda judges on the courts of Montserrat": "x",
    "Antigua and Barbuda judges on the courts of Saint Lucia": "x",
    "Antigua and Barbuda knights": "x",
    "Antigua and Barbuda Labour Party politicians": "x",
    "Antigua and Barbuda location map modules": "x",
    "Antigua and Barbuda masters athletes": "x",
    "Antigua and Barbuda modules": "x",
    "Antigua and Barbuda people of Saint Kitts and Nevis descent": "x",
    "Antigua and Barbuda Protestants": "x",
    "Antigua and Barbuda records": "x",
    "Antigua and Barbuda religion-related lists": "x",
    "Antigua and Barbuda Salvationists": "x",
    "Antigua and Barbuda Seventh-day Adventists": "x",
    "Antigua and Barbuda slave owners": "x",
    "Antigua and Barbuda social democrats": "x",
    "Antigua and Barbuda stub templates": "x",
    "Antigua and Barbuda transport-related lists": "x",
    "Antigua and Barbuda user categories": "x",
    "Antigua and Barbuda user templates": "x",
    "Antigua and Barbuda Wikipedians": "x",
    "Antigua and Barbuda–Holy See relations": "x",
    "Apostolic nuncios to Antigua and Barbuda": "x",
    "Australian judges on the courts of Antigua and Barbuda": "x",
    "Baroque architecture in Antigua and Barbuda": "x",
    "Beauty pageants in Antigua and Barbuda": "x",
    "Bilateral sports relations of Antigua and Barbuda": "x",
    "Bird family (Antigua and Barbuda)": "x",
    "British judges on the courts of Antigua and Barbuda": "x",
    "British Virgin Islands expatriates in Antigua and Barbuda": "x",
    "British Virgin Islands judges on the courts of Antigua and Barbuda": "x",
    "Buildings and structures in Saint John Parish, Antigua and Barbuda": "x",
    "By-elections in Antigua and Barbuda": "x",
    "Catholic Church in Antigua and Barbuda": "x",
    "Catholic secondary schools in Antigua and Barbuda": "x",
    "Constitution of Antigua and Barbuda": "x",
    "Country data templates of Antigua and Barbuda": "x",
    "Cricket grounds in Antigua and Barbuda": "x",
    "Dominica expatriate sportspeople in Antigua and Barbuda": "x",
    "Dominica expatriates in Antigua and Barbuda": "x",
    "Dominica judges on the courts of Antigua and Barbuda": "x",
    "Dominica people of Antigua and Barbuda descent": "x",
    "Education, sports and creative industries ministers of Antigua and Barbuda": "x",
    "Emergency services in Antigua and Barbuda": "x",
    "Endemic birds of Antigua and Barbuda": "x",
    "Endemic fauna of Antigua and Barbuda": "x",
    "Expatriate judges on the courts of Antigua and Barbuda": "x",
    "Federalism in Antigua and Barbuda": "x",
    "Folk festivals in Antigua and Barbuda": "x",
    "Ghanaian judges on the courts of Antigua and Barbuda": "x",
    "Girls' schools in Antigua and Barbuda": "x",
    "Guyanese judges on the courts of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda to Canada": "x",
    "High commissioners of Antigua and Barbuda to Saint Kitts and Nevis": "x",
    "High commissioners of Antigua and Barbuda to the United Kingdom": "x",
    "High commissioners of Australia to Antigua and Barbuda": "x",
    "High commissioners of Canada to Antigua and Barbuda": "x",
    "High commissioners of India to Antigua and Barbuda": "x",
    "High commissioners of South Africa to Antigua and Barbuda": "x",
    "High commissioners of the United Kingdom to Antigua and Barbuda": "x",
    "High schools and secondary schools in Antigua and Barbuda": "x",
    "History of sport in Antigua and Barbuda": "x",
    "Hurricanes in Antigua and Barbuda": "x",
    "Important Bird Areas of Antigua and Barbuda": "x",
    "Jamaican judges on the courts of Antigua and Barbuda": "x",
    "John Hughes, Antigua and Barbuda": "x",
    "Judicial Committee of the Privy Council cases on appeal from Antigua and Barbuda": "x",
    "Major divisions of Antigua and Barbuda": "x",
    "Members of the 14th legislature of Antigua and Barbuda": "x",
    "Members of the 15th legislature of Antigua and Barbuda": "x",
    "Members of the 16th legislature of Antigua and Barbuda": "x",
    "Members of the House of Representatives (Antigua and Barbuda)": "x",
    "Merchant ships of Antigua and Barbuda": "x",
    "Micronations in Antigua and Barbuda": "x",
    "Monarchy of Antigua and Barbuda": "x",
    "National Cultural Heritage of Antigua and Barbuda": "x",
    "National Security Council (Antigua and Barbuda)": "x",
    "Parades in Antigua and Barbuda": "x",
    "Parliaments of Antigua and Barbuda": "x",
    "People from Saint George, Antigua and Barbuda": "x",
    "People from Saint John, Antigua and Barbuda": "x",
    "People from Saint Mary, Antigua and Barbuda": "x",
    "People from Saint Paul, Antigua and Barbuda": "x",
    "People from Saint Peter, Antigua and Barbuda": "x",
    "People from Saint Philip, Antigua and Barbuda": "x",
    "Permanent representatives of Antigua and Barbuda to the World Trade Organization": "x",
    "Places in Saint John Parish, Antigua and Barbuda": "x",
    "Private islands of Antigua and Barbuda": "x",
    "Ramsar sites in Antigua and Barbuda": "x",
    "Recipients of the Order of the Nation (Antigua and Barbuda)": "x",
    "Recipients of the Order of the National Hero (Antigua and Barbuda)": "x",
    "Republicanism in Antigua and Barbuda": "x",
    "Saint George, Antigua and Barbuda": "x",
    "Saint John, Antigua and Barbuda": "x",
    "Saint Kitts and Nevis expatriates in Antigua and Barbuda": "x",
    "Saint Kitts and Nevis judges on the courts of Antigua and Barbuda": "x",
    "Saint Kitts and Nevis people of Antigua and Barbuda descent": "x",
    "Saint Lucian expatriates in Antigua and Barbuda": "x",
    "Saint Lucian judges on the courts of Antigua and Barbuda": "x",
    "Saint Lucian people of Antigua and Barbuda descent": "x",
    "Saint Mary, Antigua and Barbuda": "x",
    "Saint Paul, Antigua and Barbuda": "x",
    "Saint Peter, Antigua and Barbuda": "x",
    "Saint Philip, Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriate sportspeople in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriates in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines judges on the courts of Antigua and Barbuda": "x",
    "Scouting and Guiding in Antigua and Barbuda": "x",
    "Serbia and Montenegro expatriate sportspeople in Antigua and Barbuda": "x",
    "Socialism in Antigua and Barbuda": "x",
    "Speakers of the House of Representatives (Antigua and Barbuda)": "x",
    "United States Virgin Islands people of Antigua and Barbuda descent": "x",
    "Women ambassadors of Antigua and Barbuda": "x",
    "World Athletics Championships athletes for Antigua and Barbuda": "x",
}

to_test = [("test_antigua_and_barbuda_data_skip", data_skip)]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



#!/usr/bin/python3
"""
Unit tests for time_patterns_formats.py module.

This module provides tests for LabsYearsFormat and MatchTimes classes
which handle year-based category label generation.
"""

from ArWikiCats.translations_formats.time_patterns_formats import (
    LabsYearsFormat,
    MatchTimes,
)


class TestMatchTimes:
    """Tests for MatchTimes class."""

    def test_init(self):
        """Test initialization of MatchTimes."""
        matcher = MatchTimes()
        assert matcher is not None

    def test_match_en_time_century(self):
        """Test matching English century patterns."""
        matcher = MatchTimes()
        result = matcher.match_en_time("14th-century writers")
        assert result == "14th-century"

    def test_match_en_time_decade(self):
        """Test matching English decade patterns."""
        matcher = MatchTimes()
        result = matcher.match_en_time("1990s films")
        assert result == "1990s"

    def test_match_en_time_year(self):
        """Test matching English year patterns."""
        matcher = MatchTimes()
        result = matcher.match_en_time("2020 events")
        assert result == "2020"

    def test_match_en_time_no_match(self):
        """Test match_en_time returns empty string when no match."""
        matcher = MatchTimes()
        result = matcher.match_en_time("no time pattern here")
        assert result == ""

    def test_match_ar_time_century(self):
        """Test matching Arabic century patterns."""
        matcher = MatchTimes()
        result = matcher.match_ar_time("القرن 14 كتاب")
        assert result == "القرن 14"

    def test_match_ar_time_decade(self):
        """Test matching Arabic decade patterns."""
        matcher = MatchTimes()
        result = matcher.match_ar_time("عقد 1990 أحداث")
        assert result == "عقد 1990"

    def test_match_ar_time_year(self):
        """Test matching Arabic year patterns - plain years without prefix don't match."""
        matcher = MatchTimes()
        # Plain years without a time prefix like "سنة" or "عقد" return empty
        result = matcher.match_ar_time("2020 أحداث")
        assert result == ""


class TestLabsYearsFormat:
    """Tests for LabsYearsFormat class."""

    def test_init(self):
        """Test initialization of LabsYearsFormat."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)
        assert formatter.category_templates == templates
        assert formatter.lookup_count == 0

    def test_init_custom_placeholders(self):
        """Test initialization with custom placeholders."""
        templates = {"{time} events": "أحداث {time_ar}"}
        formatter = LabsYearsFormat(
            category_templates=templates,
            key_param_placeholder="{time}",
            value_param_placeholder="{time_ar}",
            year_param_name="time_ar",
        )
        assert formatter.key_param_placeholder == "{time}"
        assert formatter.value_param_placeholder == "{time_ar}"
        assert formatter.year_param_name == "time_ar"

    def test_lab_from_year_basic(self):
        """Test lab_from_year with basic year pattern."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        cat_year, from_year = formatter.lab_from_year("2020 events")

        assert cat_year == "2020"
        assert from_year == "أحداث 2020"

    def test_lab_from_year_century(self):
        """Test lab_from_year with century pattern."""
        templates = {"{year1} writers": "كتاب {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        cat_year, from_year = formatter.lab_from_year("14th-century writers")

        assert cat_year == "14th-century"
        assert from_year == "كتاب القرن 14"

    def test_lab_from_year_decade(self):
        """Test lab_from_year with decade pattern."""
        templates = {"{year1} films": "أفلام {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        cat_year, from_year = formatter.lab_from_year("1990s films")

        assert cat_year == "1990s"
        assert from_year == "أفلام عقد 1990"

    def test_lab_from_year_no_match(self):
        """Test lab_from_year when no year pattern matches."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        cat_year, from_year = formatter.lab_from_year("no time pattern")

        assert cat_year == ""
        assert from_year == ""

    def test_lab_from_year_no_template(self):
        """Test lab_from_year when template not found."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        cat_year, from_year = formatter.lab_from_year("2020 films")

        assert cat_year == "2020"
        assert from_year == ""

    def test_lab_from_year_with_category_prefix(self):
        """Test lab_from_year strips category: prefix."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        cat_year, from_year = formatter.lab_from_year("Category:2020 events")

        assert cat_year == "2020"
        assert from_year == "أحداث 2020"

    def test_lab_from_year_increments_lookup_count(self):
        """Test that successful lookups increment lookup_count."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        assert formatter.lookup_count == 0
        formatter.lab_from_year("2020 events")
        assert formatter.lookup_count == 1
        formatter.lab_from_year("2021 events")
        assert formatter.lookup_count == 2

    def test_lab_from_year_with_fixing_callback(self):
        """Test lab_from_year with fixing_callback."""
        templates = {"{year1} events": "أحداث {year1}"}

        def fix_callback(label):
            return label.replace("أحداث", "فعاليات")

        formatter = LabsYearsFormat(
            category_templates=templates,
            fixing_callback=fix_callback,
        )

        cat_year, from_year = formatter.lab_from_year("2020 events")

        assert from_year == "فعاليات 2020"

    def test_lab_from_year_add_basic(self):
        """Test lab_from_year_add adds a new template."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="2020 events",
            category_lab="أحداث 2020",
            en_year="2020",
            ar_year="2020",
        )

        assert result is True
        assert "{year1} events" in formatter.category_templates
        assert formatter.category_templates["{year1} events"] == "أحداث {year1}"

    def test_lab_from_year_add_missing_en_year(self):
        """Test lab_from_year_add when en_year not in category_r."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="no year events",
            category_lab="أحداث 2020",
            en_year="2020",
            ar_year="2020",
        )

        assert result is False

    def test_lab_from_year_add_missing_ar_year(self):
        """Test lab_from_year_add when ar_year not in category_lab."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="2020 events",
            category_lab="أحداث بدون سنة",
            en_year="2020",
            ar_year="2020",
        )

        assert result is False

    def test_lab_from_year_add_strips_category_prefix(self):
        """Test lab_from_year_add strips category: prefix."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="Category:2020 events",
            category_lab="أحداث 2020",
            en_year="2020",
            ar_year="2020",
        )

        assert result is True
        assert "{year1} events" in formatter.category_templates

    def test_lab_from_year_add_auto_detect_en_year(self):
        """Test lab_from_year_add auto-detects en_year when not provided."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="2020 events",
            category_lab="أحداث 2020",
            en_year="",
            ar_year="2020",
        )

        assert result is True
        assert "{year1} events" in formatter.category_templates

    def test_lab_from_year_add_auto_detect_ar_year(self):
        """Test lab_from_year_add auto-detects ar_year when not provided."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="2020 events",
            category_lab="أحداث 2020",
            en_year="2020",
            ar_year="",
        )

        assert result is True
        assert "{year1} events" in formatter.category_templates

    def test_lab_from_year_add_digit_fallback(self):
        """Test lab_from_year_add uses en_year for ar_year when en_year is digit."""
        templates = {}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.lab_from_year_add(
            category_r="2020 events",
            category_lab="أحداث 2020",
            en_year="2020",
            ar_year="",
        )

        assert result is True


class TestLabsYearsFormatInheritance:
    """Tests for LabsYearsFormat inheritance from MatchTimes."""

    def test_inherits_from_match_times(self):
        """Test that LabsYearsFormat inherits from MatchTimes."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        assert isinstance(formatter, MatchTimes)

    def test_has_match_en_time_method(self):
        """Test that LabsYearsFormat has match_en_time method from MatchTimes."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.match_en_time("2020 events")
        assert result == "2020"

    def test_has_match_ar_time_method(self):
        """Test that LabsYearsFormat has match_ar_time method from MatchTimes."""
        templates = {"{year1} events": "أحداث {year1}"}
        formatter = LabsYearsFormat(category_templates=templates)

        result = formatter.match_ar_time("أحداث 2020")
        assert result == "2020"
